@@ -1,4 +1,4 @@
-// Copyright 2020-2024 Buf Technologies, Inc.
+// Copyright 2020-2025 Buf Technologies, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -15,24 +15,36 @@
 package bufcli
 
 import (
-	"github.com/bufbuild/buf/private/bufpkg/bufapi"
+	"buf.build/go/app/appext"
 	"github.com/bufbuild/buf/private/bufpkg/bufmodule"
 	"github.com/bufbuild/buf/private/bufpkg/bufmodule/bufmoduleapi"
-	"github.com/bufbuild/buf/private/pkg/app/appext"
+	"github.com/bufbuild/buf/private/bufpkg/bufplugin"
+	"github.com/bufbuild/buf/private/bufpkg/bufplugin/bufpluginapi"
+	"github.com/bufbuild/buf/private/bufpkg/bufregistryapi/bufregistryapimodule"
+	"github.com/bufbuild/buf/private/bufpkg/bufregistryapi/bufregistryapiplugin"
 )
 
-// NewUploader returns a new Uploader.
-func NewUploader(container appext.Container) (bufmodule.Uploader, error) {
+// NewModuleUploader returns a new Uploader for ModuleSets.
+func NewModuleUploader(container appext.Container) (bufmodule.Uploader, error) {
 	clientConfig, err := NewConnectClientConfig(container)
 	if err != nil {
 		return nil, err
 	}
-	return newUploader(container, bufapi.NewClientProvider(clientConfig)), nil
+	return newModuleUploader(container, bufregistryapimodule.NewClientProvider(clientConfig)), nil
 }
 
-func newUploader(
+// NewPluginUploader returns a new Uploader for Plugins.
+func NewPluginUploader(container appext.Container) (bufplugin.Uploader, error) {
+	clientConfig, err := NewConnectClientConfig(container)
+	if err != nil {
+		return nil, err
+	}
+	return newPluginUploader(container, bufregistryapiplugin.NewClientProvider(clientConfig)), nil
+}
+
+func newModuleUploader(
 	container appext.Container,
-	clientProvider bufapi.ClientProvider,
+	clientProvider bufregistryapimodule.ClientProvider,
 ) bufmodule.Uploader {
 	return bufmoduleapi.NewUploader(
 		container.Logger(),
@@ -41,3 +53,13 @@ func newUploader(
 		bufmoduleapi.UploaderWithPublicRegistry(container.Env(publicRegistryEnvKey)),
 	)
 }
+
+func newPluginUploader(
+	container appext.Container,
+	clientProvider bufregistryapiplugin.ClientProvider,
+) bufplugin.Uploader {
+	return bufpluginapi.NewUploader(
+		container.Logger(),
+		clientProvider,
+	)
+}
