@@ -22,9 +22,15 @@ import (
 	"io/fs"
 	"log/slog"
 	"net/http"
+	"slices"
 	"sort"
 
+	"buf.build/go/app"
+	"buf.build/go/app/appcmd"
+	"buf.build/go/protovalidate"
 	"buf.build/go/protoyaml"
+	"buf.build/go/standard/xio"
+	"buf.build/go/standard/xslices"
 	"github.com/bufbuild/buf/private/buf/buffetch"
 	"github.com/bufbuild/buf/private/buf/bufwkt/bufwktstore"
 	"github.com/bufbuild/buf/private/buf/bufworkspace"
@@ -39,25 +45,23 @@ import (
 	"github.com/bufbuild/buf/private/bufpkg/bufreflect"
 	"github.com/bufbuild/buf/private/gen/data/datawkt"
 	imagev1 "github.com/bufbuild/buf/private/gen/proto/go/buf/alpha/image/v1"
-	"github.com/bufbuild/buf/private/pkg/app"
-	"github.com/bufbuild/buf/private/pkg/app/appcmd"
 	"github.com/bufbuild/buf/private/pkg/git"
 	"github.com/bufbuild/buf/private/pkg/httpauth"
-	"github.com/bufbuild/buf/private/pkg/ioext"
 	"github.com/bufbuild/buf/private/pkg/normalpath"
 	"github.com/bufbuild/buf/private/pkg/protoencoding"
-	"github.com/bufbuild/buf/private/pkg/slicesext"
 	"github.com/bufbuild/buf/private/pkg/storage/storageos"
 	"github.com/bufbuild/buf/private/pkg/syserror"
 	"github.com/bufbuild/buf/private/pkg/wasm"
-	"github.com/bufbuild/protovalidate-go"
 	"google.golang.org/protobuf/proto"
 )
 
-// ImageWithConfig pairs an Image with lint and breaking configuration.
+// ImageWithConfig pairs an Image with its corresponding [bufmodule.Module] full name
+// (which may be nil), [bufmodule.Module] opaque ID, and lint and breaking configurations.
 type ImageWithConfig interface {
 	bufimage.Image
 
+	ModuleFullName() bufparse.FullName
+	ModuleOpaqueID() string
 	LintConfig() bufconfig.LintConfig
 	BreakingConfig() bufconfig.BreakingConfig
 	PluginConfigs() []bufconfig.PluginConfig
@@ -476,20 +480,21 @@ func (c *controller) GetTargetImageWithConfigsAndCheckClient(
 		imageWithConfigs := []ImageWithConfig{
 			newImageWithConfig(
 				image,
+				nil, // No module name for a single message ref
+				"",  // No module opaque ID for a single message ref
 				lintConfig,
 				breakingConfig,
 				pluginConfigs,
 			),
 		}
-		pluginRunnerProvider := bufcheck.NewLocalRunnerProvider(
-			wasmRuntime,
-			pluginKeyProvider,
-			c.pluginDataProvider,
-		)
 		checkClient, err := bufcheck.NewClient(
 			c.logger,
-			pluginRunnerProvider,
 			bufcheck.ClientWithStderr(c.container.Stderr()),
+			bufcheck.ClientWithRunnerProvider(
+				bufcheck.NewLocalRunnerProvider(wasmRuntime),
+			),
+			bufcheck.ClientWithLocalWasmPluginsFromOS(),
+			bufcheck.ClientWithRemoteWasmPlugins(pluginKeyProvider, c.pluginDataProvider),
 		)
 		if err != nil {
 			return nil, nil, err
@@ -691,11 +696,11 @@ func (c *controller) GetMessage(
 	}
 	var validator protoyaml.Validator
 	if functionOptions.messageValidation {
-		var err error
-		validator, err = protovalidate.New()
+		protovalidateValidator, err := protovalidate.New()
 		if err != nil {
 			return nil, 0, err
 		}
+		validator = yamlValidator{protovalidateValidator}
 	}
 	var unmarshaler protoencoding.Unmarshaler
 	switch messageEncoding {
@@ -721,13 +726,10 @@ func (c *controller) GetMessage(
 	if err != nil {
 		return nil, 0, err
 	}
-	data, err := ioext.ReadAllAndClose(readCloser)
+	data, err := xio.ReadAllAndClose(readCloser)
 	if err != nil {
 		return nil, 0, err
 	}
-	if len(data) == 0 {
-		return nil, 0, fmt.Errorf("length of data read from %q was zero", messageInput)
-	}
 	message, err := bufreflect.NewMessage(ctx, schemaImage, typeName)
 	if err != nil {
 		return nil, 0, err
@@ -799,15 +801,17 @@ func (c *controller) GetCheckClientForWorkspace(
 	if err != nil {
 		return nil, err
 	}
-	pluginRunnerProvider := bufcheck.NewLocalRunnerProvider(
-		wasmRuntime,
-		pluginKeyProvider,
-		c.pluginDataProvider,
-	)
 	return bufcheck.NewClient(
 		c.logger,
-		pluginRunnerProvider,
 		bufcheck.ClientWithStderr(c.container.Stderr()),
+		bufcheck.ClientWithRunnerProvider(
+			bufcheck.NewLocalRunnerProvider(wasmRuntime),
+		),
+		bufcheck.ClientWithLocalWasmPluginsFromOS(),
+		bufcheck.ClientWithRemoteWasmPlugins(
+			pluginKeyProvider,
+			c.pluginDataProvider,
+		),
 	)
 }
 
@@ -1173,6 +1177,8 @@ func (c *controller) buildTargetImageWithConfigs(
 			imageWithConfigs,
 			newImageWithConfig(
 				image,
+				module.FullName(),
+				module.OpaqueID(),
 				workspace.GetLintConfigForOpaqueID(module.OpaqueID()),
 				workspace.GetBreakingConfigForOpaqueID(module.OpaqueID()),
 				workspace.PluginConfigs(),
@@ -1199,13 +1205,13 @@ func (c *controller) warnUnconfiguredTransitiveImports(
 	// First, figure out if we have a local module. If we don't, just return - the Workspace
 	// was purely built from remote Modules, and therefore buf.yaml configured dependencies
 	// do not apply.
-	if slicesext.Count(workspace.Modules(), bufmodule.Module.IsLocal) == 0 {
+	if xslices.Count(workspace.Modules(), bufmodule.Module.IsLocal) == 0 {
 		return nil
 	}
 	// Construct a struct map of all the FullName strings of the configured buf.yaml
 	// Module dependencies, and the local Modules. These are considered OK to depend on
 	// for non-imports in the Image.
-	configuredFullNameStrings, err := slicesext.MapError(
+	configuredFullNameStrings, err := xslices.MapError(
 		workspace.ConfiguredDepModuleRefs(),
 		func(moduleRef bufparse.Ref) (string, error) {
 			moduleFullName := moduleRef.FullName()
@@ -1218,7 +1224,7 @@ func (c *controller) warnUnconfiguredTransitiveImports(
 	if err != nil {
 		return err
 	}
-	configuredFullNameStringMap := slicesext.ToStructMap(configuredFullNameStrings)
+	configuredFullNameStringMap := xslices.ToStructMap(configuredFullNameStrings)
 	for _, localModule := range bufmodule.ModuleSetLocalModules(workspace) {
 		if moduleFullName := localModule.FullName(); moduleFullName != nil {
 			configuredFullNameStringMap[moduleFullName.String()] = struct{}{}
@@ -1290,6 +1296,15 @@ func (c *controller) handleFileAnnotationSetRetError(retErrAddr *error) {
 	}
 }
 
+// Implements [protoyaml.Validator] using [protovalidate.Validator]. This allows us to pass
+// a [protovalidate.Validator] to the [protoencoding.NewYAMLUnmarshaler] and validate types
+// when unmarshalling.
+type yamlValidator struct{ protovalidateValidator protovalidate.Validator }
+
+func (v yamlValidator) Validate(msg proto.Message) error {
+	return v.protovalidateValidator.Validate(msg)
+}
+
 func getImageFileInfosForModuleSet(ctx context.Context, moduleSet bufmodule.ModuleSet) ([]bufimage.ImageFileInfo, error) {
 	// Sorted.
 	fileInfos, err := bufmodule.GetFileInfos(
@@ -1299,7 +1314,7 @@ func getImageFileInfosForModuleSet(ctx context.Context, moduleSet bufmodule.Modu
 	if err != nil {
 		return nil, err
 	}
-	return slicesext.Map(
+	return xslices.Map(
 		fileInfos,
 		func(fileInfo bufmodule.FileInfo) bufimage.ImageFileInfo {
 			return bufimage.ImageFileInfoForModuleFileInfo(fileInfo)
@@ -1331,8 +1346,15 @@ func filterImage(
 	if functionOptions.imageExcludeImports {
 		newImage = bufimage.ImageWithoutImports(newImage)
 	}
-	if len(functionOptions.imageTypes) > 0 {
-		newImage, err = bufimageutil.ImageFilteredByTypes(newImage, functionOptions.imageTypes...)
+	includeTypes := functionOptions.imageIncludeTypes
+	excludeTypes := functionOptions.imageExcludeTypes
+	if len(includeTypes) > 0 || len(excludeTypes) > 0 {
+		newImage, err = bufimageutil.FilterImage(
+			newImage,
+			bufimageutil.WithIncludeTypes(includeTypes...),
+			bufimageutil.WithExcludeTypes(excludeTypes...),
+			bufimageutil.WithMutateInPlace(),
+		)
 		if err != nil {
 			return nil, err
 		}
@@ -1438,10 +1460,8 @@ func validateFileAnnotationErrorFormat(fileAnnotationErrorFormat string) error {
 	if fileAnnotationErrorFormat == "" {
 		return nil
 	}
-	for _, formatString := range bufanalysis.AllFormatStrings {
-		if fileAnnotationErrorFormat == formatString {
-			return nil
-		}
+	if slices.Contains(bufanalysis.AllFormatStrings, fileAnnotationErrorFormat) {
+		return nil
 	}
 	// TODO FUTURE: get standard flag names and bindings into this package.
 	fileAnnotationErrorFormatFlagName := "error-format"
@@ -1458,15 +1478,15 @@ func newStaticPluginKeyProviderForPluginConfigs(
 	pluginKeys []bufplugin.PluginKey,
 ) (_ bufplugin.PluginKeyProvider, retErr error) {
 	// Validate that all remote PluginConfigs are present in the buf.lock file.
-	pluginKeysByFullName, err := slicesext.ToUniqueValuesMap(pluginKeys, func(pluginKey bufplugin.PluginKey) string {
+	pluginKeysByFullName, err := xslices.ToUniqueValuesMap(pluginKeys, func(pluginKey bufplugin.PluginKey) string {
 		return pluginKey.FullName().String()
 	})
 	if err != nil {
 		return nil, fmt.Errorf("failed to validate remote PluginKeys: %w", err)
 	}
 	// Remote PluginConfig Refs are any PluginConfigs that have a Ref.
-	remotePluginRefs := slicesext.Filter(
-		slicesext.Map(pluginConfigs, func(pluginConfig bufconfig.PluginConfig) bufparse.Ref {
+	remotePluginRefs := xslices.Filter(
+		xslices.Map(pluginConfigs, func(pluginConfig bufconfig.PluginConfig) bufparse.Ref {
 			return pluginConfig.Ref()
 		}),
 		func(pluginRef bufparse.Ref) bool {
