@@ -1,4 +1,4 @@
-// Copyright 2020-2024 Buf Technologies, Inc.
+// Copyright 2020-2025 Buf Technologies, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -18,6 +18,7 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"maps"
 	"net/http"
 	"strconv"
 	"strings"
@@ -27,6 +28,7 @@ import (
 	reflectionv1 "github.com/bufbuild/buf/private/gen/proto/go/grpc/reflection/v1"
 	"github.com/bufbuild/buf/private/pkg/protoencoding"
 	"github.com/bufbuild/buf/private/pkg/verbose"
+	"google.golang.org/protobuf/proto"
 	"google.golang.org/protobuf/reflect/protodesc"
 	"google.golang.org/protobuf/reflect/protoreflect"
 	"google.golang.org/protobuf/reflect/protoregistry"
@@ -154,30 +156,28 @@ func (r *reflectionResolver) ListServices() ([]protoreflect.FullName, error) {
 	defer r.mu.Unlock()
 
 	r.printer.Printf("* Using server reflection to list services\n")
-	resp, err := r.sendLocked(&reflectionv1.ServerReflectionRequest{
-		MessageRequest: &reflectionv1.ServerReflectionRequest_ListServices{
-			ListServices: "",
-		},
-	})
+	resp, err := r.sendLocked(reflectionv1.ServerReflectionRequest_builder{
+		ListServices: proto.String(""),
+	}.Build())
 	if err != nil {
 		return nil, err
 	}
-	switch response := resp.MessageResponse.(type) {
-	case *reflectionv1.ServerReflectionResponse_ErrorResponse:
+	switch resp.WhichMessageResponse() {
+	case reflectionv1.ServerReflectionResponse_ErrorResponse_case:
 		// This should never happen, however we do a bounds check to ensure we are doing a safe
 		// conversion from int32 (ErrorResponse.ErrorCode) to uint32 (connect.Code).
-		if response.ErrorResponse.ErrorCode < 0 {
-			return nil, fmt.Errorf("server replied with unsupported error code: %v", response.ErrorResponse.ErrorCode)
+		if resp.GetErrorResponse().GetErrorCode() < 0 {
+			return nil, fmt.Errorf("server replied with unsupported error code: %v", resp.GetErrorResponse().GetErrorCode())
 		}
-		return nil, connect.NewWireError(connect.Code(response.ErrorResponse.ErrorCode), errors.New(response.ErrorResponse.ErrorMessage))
-	case *reflectionv1.ServerReflectionResponse_ListServicesResponse:
-		serviceNames := make([]protoreflect.FullName, len(response.ListServicesResponse.Service))
-		for i, service := range response.ListServicesResponse.Service {
-			serviceNames[i] = protoreflect.FullName(service.Name)
+		return nil, connect.NewWireError(connect.Code(resp.GetErrorResponse().GetErrorCode()), errors.New(resp.GetErrorResponse().GetErrorMessage()))
+	case reflectionv1.ServerReflectionResponse_ListServicesResponse_case:
+		serviceNames := make([]protoreflect.FullName, len(resp.GetListServicesResponse().GetService()))
+		for i, service := range resp.GetListServicesResponse().GetService() {
+			serviceNames[i] = protoreflect.FullName(service.GetName())
 		}
 		return serviceNames, nil
 	default:
-		return nil, fmt.Errorf("server replied with unsupported response type: %T", resp.MessageResponse)
+		return nil, fmt.Errorf("server replied with unsupported response type: %v", resp.WhichMessageResponse())
 	}
 }
 
@@ -300,11 +300,9 @@ func (r *reflectionResolver) FindExtensionByNumber(message protoreflect.FullName
 
 func (r *reflectionResolver) fileContainingSymbolLocked(name protoreflect.FullName) ([]*descriptorpb.FileDescriptorProto, error) {
 	r.printer.Printf("* Using server reflection to resolve %q\n", name)
-	resp, err := r.sendLocked(&reflectionv1.ServerReflectionRequest{
-		MessageRequest: &reflectionv1.ServerReflectionRequest_FileContainingSymbol{
-			FileContainingSymbol: string(name),
-		},
-	})
+	resp, err := r.sendLocked(reflectionv1.ServerReflectionRequest_builder{
+		FileContainingSymbol: proto.String(string(name)),
+	}.Build())
 	if err != nil {
 		return nil, err
 	}
@@ -313,14 +311,12 @@ func (r *reflectionResolver) fileContainingSymbolLocked(name protoreflect.FullNa
 
 func (r *reflectionResolver) fileContainingExtensionLocked(message protoreflect.FullName, field protoreflect.FieldNumber) ([]*descriptorpb.FileDescriptorProto, error) {
 	r.printer.Printf("* Using server reflection to retrieve extension %d for %q\n", field, message)
-	resp, err := r.sendLocked(&reflectionv1.ServerReflectionRequest{
-		MessageRequest: &reflectionv1.ServerReflectionRequest_FileContainingExtension{
-			FileContainingExtension: &reflectionv1.ExtensionRequest{
-				ContainingType:  string(message),
-				ExtensionNumber: int32(field),
-			},
-		},
-	})
+	resp, err := r.sendLocked(reflectionv1.ServerReflectionRequest_builder{
+		FileContainingExtension: reflectionv1.ExtensionRequest_builder{
+			ContainingType:  string(message),
+			ExtensionNumber: int32(field),
+		}.Build(),
+	}.Build())
 	if err != nil {
 		return nil, err
 	}
@@ -329,11 +325,9 @@ func (r *reflectionResolver) fileContainingExtensionLocked(message protoreflect.
 
 func (r *reflectionResolver) fileByNameLocked(name string) ([]*descriptorpb.FileDescriptorProto, error) {
 	r.printer.Printf("* Using server reflection to download file %q\n", name)
-	resp, err := r.sendLocked(&reflectionv1.ServerReflectionRequest{
-		MessageRequest: &reflectionv1.ServerReflectionRequest_FileByFilename{
-			FileByFilename: name,
-		},
-	})
+	resp, err := r.sendLocked(reflectionv1.ServerReflectionRequest_builder{
+		FileByFilename: proto.String(name),
+	}.Build())
 	if err != nil {
 		return nil, err
 	}
@@ -341,17 +335,17 @@ func (r *reflectionResolver) fileByNameLocked(name string) ([]*descriptorpb.File
 }
 
 func descriptorsInResponse(resp *reflectionv1.ServerReflectionResponse) ([]*descriptorpb.FileDescriptorProto, error) {
-	switch response := resp.MessageResponse.(type) {
-	case *reflectionv1.ServerReflectionResponse_ErrorResponse:
+	switch resp.WhichMessageResponse() {
+	case reflectionv1.ServerReflectionResponse_ErrorResponse_case:
 		// This should never happen, however we do a bounds check to ensure we are doing a safe
 		// conversion from int32 (ErrorResponse.ErrorCode) to uint32 (connect.Code).
-		if response.ErrorResponse.ErrorCode < 0 {
-			return nil, fmt.Errorf("server replied with unsupported error code: %v", response.ErrorResponse.ErrorCode)
+		if resp.GetErrorResponse().GetErrorCode() < 0 {
+			return nil, fmt.Errorf("server replied with unsupported error code: %v", resp.GetErrorResponse().GetErrorCode())
 		}
-		return nil, connect.NewWireError(connect.Code(response.ErrorResponse.ErrorCode), errors.New(response.ErrorResponse.ErrorMessage))
-	case *reflectionv1.ServerReflectionResponse_FileDescriptorResponse:
-		files := make([]*descriptorpb.FileDescriptorProto, len(response.FileDescriptorResponse.FileDescriptorProto))
-		for i, data := range response.FileDescriptorResponse.FileDescriptorProto {
+		return nil, connect.NewWireError(connect.Code(resp.GetErrorResponse().GetErrorCode()), errors.New(resp.GetErrorResponse().GetErrorMessage()))
+	case reflectionv1.ServerReflectionResponse_FileDescriptorResponse_case:
+		files := make([]*descriptorpb.FileDescriptorProto, len(resp.GetFileDescriptorResponse().GetFileDescriptorProto()))
+		for i, data := range resp.GetFileDescriptorResponse().GetFileDescriptorProto() {
 			var file descriptorpb.FileDescriptorProto
 			if err := protoencoding.NewWireUnmarshaler(nil).Unmarshal(data, &file); err != nil {
 				return nil, err
@@ -360,7 +354,7 @@ func descriptorsInResponse(resp *reflectionv1.ServerReflectionResponse) ([]*desc
 		}
 		return files, nil
 	default:
-		return nil, fmt.Errorf("server replied with unsupported response type: %T", resp.MessageResponse)
+		return nil, fmt.Errorf("server replied with unsupported response type: %v", resp.WhichMessageResponse())
 	}
 }
 
@@ -479,9 +473,7 @@ func (r *reflectionResolver) maybeCreateStreamLocked(client *reflectClient, stre
 		return false // already created
 	}
 	*stream = client.CallBidiStream(r.ctx)
-	for k, v := range r.headers {
-		(*stream).RequestHeader()[k] = v
-	}
+	maps.Copy((*stream).RequestHeader(), r.headers)
 	return true
 }
 
@@ -520,12 +512,12 @@ type extensionContainer interface {
 
 func registerExtensions(reg *protoregistry.Types, descriptor extensionContainer) {
 	exts := descriptor.Extensions()
-	for i := 0; i < exts.Len(); i++ {
+	for i := range exts.Len() {
 		extType := dynamicpb.NewExtensionType(exts.Get(i))
 		_ = reg.RegisterExtension(extType)
 	}
 	msgs := descriptor.Messages()
-	for i := 0; i < msgs.Len(); i++ {
+	for i := range msgs.Len() {
 		registerExtensions(reg, msgs.Get(i))
 	}
 }
