@@ -1,4 +1,4 @@
-// Copyright 2020-2024 Buf Technologies, Inc.
+// Copyright 2020-2025 Buf Technologies, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -25,7 +25,6 @@ import (
 	"unicode/utf8"
 
 	"github.com/bufbuild/protocompile/ast"
-	"go.uber.org/multierr"
 )
 
 // formatter writes an *ast.FileNode as a .proto file.
@@ -127,7 +126,7 @@ func (f *formatter) In() {
 func (f *formatter) Out() {
 	if f.indent <= 0 {
 		// Unreachable.
-		f.err = multierr.Append(
+		f.err = errors.Join(
 			f.err,
 			errors.New("internal error: attempted to decrement indentation at zero"),
 		)
@@ -155,7 +154,7 @@ func (f *formatter) Indent(nextNode ast.Node) {
 // WriteString writes the given element to the generated output.
 //
 // This will not write indentation or newlines. Use P if you
-// want to emit identation or newlines.
+// want to emit indentation or newlines.
 func (f *formatter) WriteString(elem string) {
 	if f.pendingSpace {
 		f.pendingSpace = false
@@ -180,7 +179,7 @@ func (f *formatter) WriteString(elem string) {
 		if !strings.ContainsRune(prevBlockList, f.lastWritten) &&
 			!strings.ContainsRune(nextBlockList, first) {
 			if _, err := f.writer.Write([]byte{' '}); err != nil {
-				f.err = multierr.Append(f.err, err)
+				f.err = errors.Join(f.err, err)
 				return
 			}
 		}
@@ -190,7 +189,7 @@ func (f *formatter) WriteString(elem string) {
 	}
 	f.lastWritten, _ = utf8.DecodeLastRuneInString(elem)
 	if _, err := f.writer.Write([]byte(elem)); err != nil {
-		f.err = multierr.Append(f.err, err)
+		f.err = errors.Join(f.err, err)
 	}
 }
 
@@ -501,7 +500,7 @@ func (f *formatter) writeOptionPrefix(optionNode *ast.OptionNode) {
 //	(custom.thing)
 //	(custom.thing).bridge.(another.thing)
 func (f *formatter) writeOptionName(optionNameNode *ast.OptionNameNode) {
-	for i := 0; i < len(optionNameNode.Parts); i++ {
+	for i := range optionNameNode.Parts {
 		if f.inCompactOptions && i == 0 {
 			// The leading comments of the first token (either open rune or the
 			// name) will have already been written, so we need to handle this
@@ -749,7 +748,7 @@ func arrayLiteralHasNestedMessageOrArray(arrayLiteralNode *ast.ArrayLiteralNode)
 //	foo: 1
 //	foo: 2
 func (f *formatter) writeMessageLiteralElements(messageLiteralNode *ast.MessageLiteralNode) {
-	for i := 0; i < len(messageLiteralNode.Elements); i++ {
+	for i := range messageLiteralNode.Elements {
 		// Separators ("," or ";") are optional. To avoid inconsistent formatted output,
 		// we suppress them, since they aren't needed. So we just write the element and
 		// ignore any optional separator in the AST.
@@ -887,7 +886,7 @@ func (f *formatter) writeField(fieldNode *ast.FieldNode) {
 		// If a label was not written, the multiline comments will be
 		// attached to the type.
 		if compoundIdentNode, ok := fieldNode.FldType.(*ast.CompoundIdentNode); ok {
-			f.writeCompountIdentForFieldName(compoundIdentNode)
+			f.writeCompoundIdentForFieldName(compoundIdentNode)
 		} else {
 			f.writeStart(fieldNode.FldType)
 		}
@@ -1141,7 +1140,7 @@ func (f *formatter) writeGroup(groupNode *ast.GroupNode) {
 func (f *formatter) writeExtensionRange(extensionRangeNode *ast.ExtensionRangeNode) {
 	f.writeStart(extensionRangeNode.Keyword)
 	f.Space()
-	for i := 0; i < len(extensionRangeNode.Ranges); i++ {
+	for i := range extensionRangeNode.Ranges {
 		if i > 0 {
 			// The length of this slice must be exactly len(Ranges)-1.
 			f.writeInline(extensionRangeNode.Commas[i-1])
@@ -1180,7 +1179,7 @@ func (f *formatter) writeReserved(reservedNode *ast.ReservedNode) {
 		}
 	}
 	f.Space()
-	for i := 0; i < len(elements); i++ {
+	for i := range elements {
 		if i > 0 {
 			// The length of this slice must be exactly len({Names,Ranges})-1.
 			f.writeInline(reservedNode.Commas[i-1])
@@ -1328,7 +1327,7 @@ func (f *formatter) writeArrayLiteral(arrayLiteralNode *ast.ArrayLiteralNode) {
 	var elementWriterFunc func()
 	if len(arrayLiteralNode.Elements) > 0 {
 		elementWriterFunc = func() {
-			for i := 0; i < len(arrayLiteralNode.Elements); i++ {
+			for i := range arrayLiteralNode.Elements {
 				lastElement := i == len(arrayLiteralNode.Elements)-1
 				if compositeNode, ok := arrayLiteralNode.Elements[i].(ast.CompositeNode); ok {
 					f.writeCompositeValueForArrayLiteral(compositeNode, lastElement)
@@ -1389,7 +1388,7 @@ func (f *formatter) writeCompositeValueForArrayLiteral(
 	case *ast.MessageLiteralNode:
 		f.writeMessageLiteralForArray(node, lastElement)
 	default:
-		f.err = multierr.Append(f.err, fmt.Errorf("unexpected array value node %T", node))
+		f.err = errors.Join(f.err, fmt.Errorf("unexpected array value node %T", node))
 	}
 }
 
@@ -1492,7 +1491,7 @@ func (f *formatter) writeCompoundIdent(compoundIdentNode *ast.CompoundIdentNode)
 	if compoundIdentNode.LeadingDot != nil {
 		f.writeInline(compoundIdentNode.LeadingDot)
 	}
-	for i := 0; i < len(compoundIdentNode.Components); i++ {
+	for i := range compoundIdentNode.Components {
 		if i > 0 {
 			// The length of this slice must be exactly len(Components)-1.
 			f.writeInline(compoundIdentNode.Dots[i-1])
@@ -1501,7 +1500,7 @@ func (f *formatter) writeCompoundIdent(compoundIdentNode *ast.CompoundIdentNode)
 	}
 }
 
-// writeCompountIdentForFieldName writes a compound identifier, but handles comments
+// writeCompoundIdentForFieldName writes a compound identifier, but handles comments
 // specially for field names.
 //
 // For example,
@@ -1510,11 +1509,11 @@ func (f *formatter) writeCompoundIdent(compoundIdentNode *ast.CompoundIdentNode)
 //	  // These are comments attached to bar.
 //	  bar.v1.Bar bar = 1;
 //	}
-func (f *formatter) writeCompountIdentForFieldName(compoundIdentNode *ast.CompoundIdentNode) {
+func (f *formatter) writeCompoundIdentForFieldName(compoundIdentNode *ast.CompoundIdentNode) {
 	if compoundIdentNode.LeadingDot != nil {
 		f.writeStart(compoundIdentNode.LeadingDot)
 	}
-	for i := 0; i < len(compoundIdentNode.Components); i++ {
+	for i := range compoundIdentNode.Components {
 		if i == 0 && compoundIdentNode.LeadingDot == nil {
 			f.writeStart(compoundIdentNode.Components[i])
 			continue
@@ -1779,7 +1778,7 @@ func (f *formatter) writeNode(node ast.Node) {
 	case *ast.EmptyDeclNode:
 		// Nothing to do here.
 	default:
-		f.err = multierr.Append(f.err, fmt.Errorf("unexpected node: %T", node))
+		f.err = errors.Join(f.err, fmt.Errorf("unexpected node: %T", node))
 	}
 }
 
@@ -2056,7 +2055,7 @@ func (f *formatter) writeMultilineComments(comments ast.Comments) {
 
 func (f *formatter) writeMultilineCommentsMaybeCompact(comments ast.Comments, forceCompact bool) {
 	compact := forceCompact || isOpenBrace(f.previousNode)
-	for i := 0; i < comments.Len(); i++ {
+	for i := range comments.Len() {
 		comment := comments.Index(i)
 		if !compact && newlineCount(comment.LeadingWhitespace()) > 1 {
 			// Newlines between blocks of comments should be preserved.
@@ -2097,7 +2096,7 @@ func (f *formatter) writeMultilineCommentsMaybeCompact(comments ast.Comments, fo
 //	  optional string label = 20000;
 //	}
 func (f *formatter) writeInlineComments(comments ast.Comments) {
-	for i := 0; i < comments.Len(); i++ {
+	for i := range comments.Len() {
 		if i > 0 || comments.Index(i).LeadingWhitespace() != "" || f.lastWritten == ';' || f.lastWritten == '}' {
 			f.Space()
 		}
@@ -2133,7 +2132,7 @@ func (f *formatter) writeInlineComments(comments ast.Comments) {
 //	// This comment is attached to the '}'
 //	// So is this one.
 func (f *formatter) writeTrailingEndComments(comments ast.Comments) {
-	for i := 0; i < comments.Len(); i++ {
+	for i := range comments.Len() {
 		comment := comments.Index(i)
 		if i > 0 || comment.LeadingWhitespace() != "" {
 			f.Space()
@@ -2304,7 +2303,7 @@ func computeIndent(s string) (int, bool) {
 func (f *formatter) leadingCommentsContainBlankLine(n ast.Node) bool {
 	info := f.nodeInfo(n)
 	comments := info.LeadingComments()
-	for i := 0; i < comments.Len(); i++ {
+	for i := range comments.Len() {
 		if newlineCount(comments.Index(i).LeadingWhitespace()) > 1 {
 			return true
 		}
