@@ -28,33 +28,35 @@ import (
 	"strings"
 	"time"
 
+	"buf.build/go/standard/xio"
+	"buf.build/go/standard/xlog/xslog"
 	"github.com/bufbuild/buf/private/buf/bufworkspace"
 	"github.com/bufbuild/buf/private/bufpkg/bufanalysis"
 	"github.com/bufbuild/buf/private/bufpkg/bufcheck"
 	"github.com/bufbuild/buf/private/bufpkg/bufimage"
 	"github.com/bufbuild/buf/private/bufpkg/bufmodule"
 	"github.com/bufbuild/buf/private/pkg/git"
-	"github.com/bufbuild/buf/private/pkg/ioext"
 	"github.com/bufbuild/buf/private/pkg/normalpath"
-	"github.com/bufbuild/buf/private/pkg/slogext"
 	"github.com/bufbuild/buf/private/pkg/storage"
 	"github.com/bufbuild/protocompile/ast"
 	"github.com/bufbuild/protocompile/parser"
 	"github.com/bufbuild/protocompile/reporter"
 	"go.lsp.dev/protocol"
+	"go.lsp.dev/uri"
 )
 
 const (
-	descriptorPath      = "google/protobuf/descriptor.proto"
-	refreshCheckStagger = 5 * time.Millisecond
+	descriptorPath     = "google/protobuf/descriptor.proto"
+	checkRefreshPeriod = 3 * time.Second
 )
 
 // file is a file that has been opened by the client.
 //
 // Mutating a file is thread-safe.
 type file struct {
-	lsp *lsp
-	uri protocol.URI
+	lsp       *lsp
+	uri       protocol.URI
+	checkWork chan<- struct{}
 
 	text string
 	// Version is an opaque version identifier given to us by the LSP client. This
@@ -134,6 +136,10 @@ func (f *file) Reset(ctx context.Context) {
 // for this file.
 func (f *file) Close(ctx context.Context) {
 	f.lsp.fileManager.Close(ctx, f.uri)
+	if f.checkWork != nil {
+		close(f.checkWork)
+		f.checkWork = nil
+	}
 }
 
 // IsOpenInEditor returns whether this file was opened in the LSP client's
@@ -210,7 +216,7 @@ func (f *file) RefreshSettings(ctx context.Context) {
 			f.lsp.logger.Warn(
 				"failed to validate buf.againstGit",
 				slog.String("uri", string(f.uri)),
-				slogext.ErrorAttr(err),
+				xslog.ErrorAttr(err),
 			)
 			f.againstGitRef = ""
 		} else {
@@ -290,28 +296,7 @@ func (f *file) Refresh(ctx context.Context) {
 	f.FindModule(ctx)
 
 	progress.Report(ctx, "Running Checks", 4.0/6)
-	// Since checks are a more expensive operation, we do not want to run a check on every
-	// Refresh call. Instead, we can stagger the checks and only run them periodically by
-	// spinning them off into a go routine. Then we attempt to lock using the top-level LSP
-	// lock. It is safe to use because if another LSP call is made, we allow checks to finish
-	// before resolving a subsequent LSP request.
-	go func() {
-		// We stagger the check operation by 5ms and run it for the latest Refresh state.
-		time.Sleep(refreshCheckStagger)
-		// Call TryLock, if unnsuccessful, then another thread holds the lock, so we provide a
-		// debug log and move on.
-		if !f.lsp.lock.TryLock() {
-			f.lsp.logger.Debug(
-				fmt.Sprintf("another thread holds the LSP lock, no new checks started for %v", f.uri),
-			)
-			return
-		}
-		// We have successfully obtained the lock, we can now run the checks.
-		defer f.lsp.lock.Unlock()
-		f.BuildImages(ctx)
-		f.RunLints(ctx)
-		f.RunBreaking(ctx)
-	}()
+	f.RunChecks(ctx)
 
 	progress.Report(ctx, "Indexing Symbols", 5.0/6)
 	f.IndexSymbols(ctx)
@@ -324,6 +309,58 @@ func (f *file) Refresh(ctx context.Context) {
 	f.PublishDiagnostics(ctx)
 }
 
+// RunChecks initiates background checks (lint and breaking) on this file and
+// returns immediately.
+//
+// Checks are executed in a background goroutine to avoid blocking the LSP
+// call. Each call to RunChecks invalidates any ongoing checks, triggering a
+// fresh run. However, previous checks are not interrupted. The checks acquire
+// the LSP mutex. Subsequent LSP calls will wait for the current check to
+// complete before proceeding.
+//
+// Checks are debounce (with the delay defined by checkRefreshPeriod) to avoid
+// overwhelming the client with expensive checks. If the file is not open in the
+// editor, checks are skipped. Diagnostics are published after checks are run.
+func (f *file) RunChecks(ctx context.Context) {
+	// If we have not yet started a goroutine to run checks, start one.
+	// This goroutine will run checks in the background and publish diagnostics.
+	// We debounce checks to avoid spamming the client.
+	if f.checkWork == nil {
+		// We use a buffered channel of length one as the check invalidation mechanism.
+		work := make(chan struct{}, 1)
+		f.checkWork = work
+		runChecks := func(ctx context.Context) {
+			f.lsp.lock.Lock()
+			defer f.lsp.lock.Unlock()
+			if !f.IsOpenInEditor() {
+				// Skip checks if the file is not open in the editor.
+				return
+			}
+			f.lsp.logger.Info(fmt.Sprintf("running checks for %v, %v", f.uri, f.version))
+			f.BuildImages(ctx)
+			f.RunLints(ctx)
+			f.RunBreaking(ctx)
+			f.PublishDiagnostics(ctx) // Publish the latest diagnostics.
+		}
+		// Start a goroutine to process checks.
+		go func() {
+			// Detach from the parent RPC context.
+			ctx := context.WithoutCancel(ctx)
+			for range work {
+				runChecks(ctx)
+				// Debounce checks to prevent thrashing expensive checks.
+				time.Sleep(checkRefreshPeriod)
+			}
+		}()
+	}
+	// Signal the goroutine to invalidate and rerun checks.
+	select {
+	case f.checkWork <- struct{}{}:
+	default:
+		// Channel is full, checks are already invalidated and will be rerun.
+	}
+}
+
 // RefreshAST reparses the file and generates diagnostics if necessary.
 //
 // Returns whether a reparse was necessary.
@@ -368,7 +405,7 @@ func (f *file) PublishDiagnostics(ctx context.Context) {
 		return
 	}
 
-	defer slogext.DebugProfile(f.lsp.logger, slog.String("uri", string(f.uri)))()
+	defer xslog.DebugProfile(f.lsp.logger, slog.String("uri", string(f.uri)))()
 
 	// NOTE: We need to avoid sending a JSON null here, so we replace it with
 	// a non-nil empty slice when the diagnostics slice is nil.
@@ -391,14 +428,14 @@ func (f *file) PublishDiagnostics(ctx context.Context) {
 func (f *file) FindModule(ctx context.Context) {
 	workspace, err := f.lsp.controller.GetWorkspace(ctx, f.uri.Filename())
 	if err != nil {
-		f.lsp.logger.Warn("could not load workspace", slog.String("uri", string(f.uri)), slogext.ErrorAttr(err))
+		f.lsp.logger.Warn("could not load workspace", slog.String("uri", string(f.uri)), xslog.ErrorAttr(err))
 		return
 	}
 
 	// Get the check client for this workspace.
 	checkClient, err := f.lsp.controller.GetCheckClientForWorkspace(ctx, workspace, f.lsp.wasmRuntime)
 	if err != nil {
-		f.lsp.logger.Warn("could not get check client", slogext.ErrorAttr(err))
+		f.lsp.logger.Warn("could not get check client", xslog.ErrorAttr(err))
 		return
 	}
 
@@ -434,7 +471,7 @@ func (f *file) FindModule(ctx context.Context) {
 
 // IndexImports finds URIs for all of the files imported by this file.
 func (f *file) IndexImports(ctx context.Context) {
-	defer slogext.DebugProfile(f.lsp.logger, slog.String("uri", string(f.uri)))()
+	defer xslog.DebugProfile(f.lsp.logger, slog.String("uri", string(f.uri)))()
 
 	if f.fileNode == nil || f.importToFile != nil {
 		return
@@ -518,7 +555,7 @@ func (f *file) IndexImports(ctx context.Context) {
 		if fileInfo.LocalPath() == f.uri.Filename() {
 			imported = f
 		} else {
-			imported = f.Manager().Open(ctx, protocol.URI("file://"+fileInfo.LocalPath()))
+			imported = f.Manager().Open(ctx, uri.File(fileInfo.LocalPath()))
 		}
 
 		imported.objectInfo = fileInfo
@@ -528,7 +565,7 @@ func (f *file) IndexImports(ctx context.Context) {
 	// descriptor.proto is always implicitly imported.
 	if _, ok := f.importToFile[descriptorPath]; !ok {
 		descriptorFile := importable[descriptorPath]
-		descriptorURI := protocol.URI("file://" + descriptorFile.LocalPath())
+		descriptorURI := uri.File(descriptorFile.LocalPath())
 		if f.uri == descriptorURI {
 			f.importToFile[descriptorPath] = f
 		} else {
@@ -568,16 +605,16 @@ func (f *file) newFileOpener() fileOpener {
 	}
 
 	return func(path string) (io.ReadCloser, error) {
-		var uri protocol.URI
+		var newURI protocol.URI
 		fileInfo, ok := f.importablePathToObject[path]
 		if ok {
-			uri = protocol.URI("file://" + fileInfo.LocalPath())
+			newURI = uri.File(fileInfo.LocalPath())
 		} else {
-			uri = protocol.URI("file://" + path)
+			newURI = uri.File(path)
 		}
 
-		if file := f.Manager().Get(uri); file != nil {
-			return ioext.CompositeReadCloser(strings.NewReader(file.text), ioext.NopCloser), nil
+		if file := f.Manager().Get(newURI); file != nil {
+			return xio.CompositeReadCloser(strings.NewReader(file.text), xio.NopCloser), nil
 		} else if !ok {
 			return nil, os.ErrNotExist
 		}
@@ -624,7 +661,7 @@ func (f *file) newAgainstFileOpener(ctx context.Context) fileOpener {
 			return os.Open(fileInfo.LocalPath())
 		}
 
-		return ioext.CompositeReadCloser(bytes.NewReader(data), ioext.NopCloser), err
+		return xio.CompositeReadCloser(bytes.NewReader(data), xio.NopCloser), err
 	}
 }
 
@@ -726,7 +763,7 @@ func (f *file) appendLintErrors(source string, err error) bool {
 		f.lsp.logger.Warn(
 			"error while linting",
 			slog.String("uri", string(f.uri)),
-			slogext.ErrorAttr(err),
+			xslog.ErrorAttr(err),
 		)
 		return false
 	}
@@ -744,7 +781,7 @@ func (f *file) appendLintErrors(source string, err error) bool {
 				},
 			},
 			Code:     annotation.Type(),
-			Severity: protocol.DiagnosticSeverityError,
+			Severity: protocol.DiagnosticSeverityWarning,
 			Source:   source,
 			Message:  annotation.Message(),
 		})
@@ -756,7 +793,7 @@ func (f *file) appendLintErrors(source string, err error) bool {
 // IndexSymbols processes the AST of a file and generates symbols for each symbol in
 // the document.
 func (f *file) IndexSymbols(ctx context.Context) {
-	defer slogext.DebugProfile(f.lsp.logger, slog.String("uri", string(f.uri)))()
+	defer xslog.DebugProfile(f.lsp.logger, slog.String("uri", string(f.uri)))()
 
 	// Throw away all the old symbols. Unlike other indexing functions, we rebuild
 	// symbols unconditionally. This is because if this file depends on a file
