@@ -1,4 +1,4 @@
-// Copyright 2020-2024 Buf Technologies, Inc.
+// Copyright 2020-2025 Buf Technologies, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -21,39 +21,36 @@ import (
 	"io"
 	"io/fs"
 	"log/slog"
+	"slices"
 	"sort"
 	"strings"
 
 	"buf.build/go/bufplugin/check"
+	"buf.build/go/standard/xslices"
 	"github.com/bufbuild/buf/private/bufpkg/bufcheck"
+	"github.com/bufbuild/buf/private/bufpkg/bufcheck/bufcheckserver"
 	"github.com/bufbuild/buf/private/bufpkg/bufconfig"
 	"github.com/bufbuild/buf/private/bufpkg/bufmodule"
-	"github.com/bufbuild/buf/private/pkg/command"
+	"github.com/bufbuild/buf/private/bufpkg/bufparse"
 	"github.com/bufbuild/buf/private/pkg/normalpath"
-	"github.com/bufbuild/buf/private/pkg/slicesext"
 	"github.com/bufbuild/buf/private/pkg/storage"
 	"github.com/bufbuild/buf/private/pkg/storage/storagemem"
-	"github.com/bufbuild/buf/private/pkg/wasm"
 	"github.com/google/uuid"
-	"go.uber.org/multierr"
 )
 
 type migrator struct {
 	logger            *slog.Logger
-	runner            command.Runner
 	moduleKeyProvider bufmodule.ModuleKeyProvider
 	commitProvider    bufmodule.CommitProvider
 }
 
 func newMigrator(
 	logger *slog.Logger,
-	runner command.Runner,
 	moduleKeyProvider bufmodule.ModuleKeyProvider,
 	commitProvider bufmodule.CommitProvider,
 ) *migrator {
 	return &migrator{
 		logger:            logger,
-		runner:            runner,
 		moduleKeyProvider: moduleKeyProvider,
 		commitProvider:    commitProvider,
 	}
@@ -119,16 +116,16 @@ func (m *migrator) getMigrateBuilder(
 	// Directories cannot jump context because in the migrated buf.yaml v2, each
 	// directory path cannot jump context. I.e. it's not valid to have `- path: ..`
 	// in a buf.yaml v2.
-	workspaceDirPaths, err := slicesext.MapError(workspaceDirPaths, normalpath.NormalizeAndValidate)
+	workspaceDirPaths, err := xslices.MapError(workspaceDirPaths, normalpath.NormalizeAndValidate)
 	if err != nil {
 		return nil, err
 	}
-	moduleDirPaths, err = slicesext.MapError(moduleDirPaths, normalpath.NormalizeAndValidate)
+	moduleDirPaths, err = xslices.MapError(moduleDirPaths, normalpath.NormalizeAndValidate)
 	if err != nil {
 		return nil, err
 	}
 	// This does mean that buf.gen.yamls need to be under the directory this is run at, but this is OK.
-	bufGenYAMLFilePaths, err = slicesext.MapError(bufGenYAMLFilePaths, normalpath.NormalizeAndValidate)
+	bufGenYAMLFilePaths, err = xslices.MapError(bufGenYAMLFilePaths, normalpath.NormalizeAndValidate)
 	if err != nil {
 		return nil, err
 	}
@@ -140,7 +137,6 @@ func (m *migrator) getMigrateBuilder(
 	}
 	migrateBuilder := newMigrateBuilder(
 		m.logger,
-		m.runner,
 		m.commitProvider,
 		bucket,
 		destinationDirPath,
@@ -167,7 +163,7 @@ func (m *migrator) getMigrateBuilder(
 }
 
 func (m *migrator) migrate(ctx context.Context, bucket storage.WriteBucket, migrateBuilder *migrateBuilder) (retErr error) {
-	for _, path := range slicesext.MapKeysToSortedSlice(migrateBuilder.pathsToDelete) {
+	for _, path := range xslices.MapKeysToSortedSlice(migrateBuilder.pathsToDelete) {
 		if err := bucket.Delete(ctx, path); err != nil {
 			return err
 		}
@@ -209,7 +205,6 @@ func (m *migrator) diff(
 	}
 	return storage.Diff(
 		ctx,
-		m.runner,
 		writer,
 		originalFileBucket,
 		addedFileBucket,
@@ -262,7 +257,7 @@ func (m *migrator) getOriginalAndAddedFileBuckets(
 			return nil, nil, err
 		}
 		defer func() {
-			retErr = multierr.Append(retErr, writeObjectCloser.Close())
+			retErr = errors.Join(retErr, writeObjectCloser.Close())
 		}()
 		if err := bufconfig.WriteBufYAMLFile(writeObjectCloser, migratedBufYAMLFile); err != nil {
 			return nil, nil, err
@@ -285,7 +280,7 @@ func (m *migrator) getOriginalAndAddedFileBuckets(
 				return nil, nil, err
 			}
 			defer func() {
-				retErr = multierr.Append(retErr, writeObjectCloser.Close())
+				retErr = errors.Join(retErr, writeObjectCloser.Close())
 			}()
 			if err := bufconfig.WriteBufLockFile(writeObjectCloser, migratedBufLockFile); err != nil {
 				return nil, nil, err
@@ -309,7 +304,7 @@ func (m *migrator) getOriginalAndAddedFileBuckets(
 			return nil, nil, err
 		}
 		defer func() {
-			retErr = multierr.Append(retErr, writeObjectCloser.Close())
+			retErr = errors.Join(retErr, writeObjectCloser.Close())
 		}()
 		if err := bufconfig.WriteBufGenYAMLFile(writeObjectCloser, migratedBufGenYAMLFile); err != nil {
 			return nil, nil, err
@@ -325,9 +320,9 @@ func (m *migrator) buildBufYAMLAndBufLockFiles(
 	migrateBuilder *migrateBuilder,
 ) (bufconfig.BufYAMLFile, bufconfig.BufLockFile, error) {
 	// module full name --> the list of declared dependencies that are this module.
-	depModuleToDeclaredRefs := make(map[string][]bufmodule.ModuleRef)
+	depModuleToDeclaredRefs := make(map[string][]bufparse.Ref)
 	for _, declaredRef := range migrateBuilder.configuredDepModuleRefs {
-		moduleFullName := declaredRef.ModuleFullName().String()
+		moduleFullName := declaredRef.FullName().String()
 		// If a declared dependency also shows up in the workspace, it's not a dependency.
 		if _, ok := migrateBuilder.moduleFullNameStringToParentPath[moduleFullName]; ok {
 			continue
@@ -337,11 +332,11 @@ func (m *migrator) buildBufYAMLAndBufLockFiles(
 	// module full name --> the list of lock entries that are this module.
 	depModuleToLockEntries := make(map[string][]bufmodule.ModuleKey)
 	for _, lockEntry := range migrateBuilder.depModuleKeys {
-		moduleFullName := lockEntry.ModuleFullName().String()
+		moduleFullName := lockEntry.FullName().String()
 		// If a declared dependency also shows up in the workspace, it's not a dependency.
 		//
 		// We are only removing lock entries that are in the workspace. A lock entry
-		// could be for an indirect dependenceny not listed in deps in any buf.yaml.
+		// could be for an indirect dependency not listed in deps in any buf.yaml.
 		if _, ok := migrateBuilder.moduleFullNameStringToParentPath[moduleFullName]; ok {
 			continue
 		}
@@ -350,9 +345,9 @@ func (m *migrator) buildBufYAMLAndBufLockFiles(
 	// This will be set to false if the duplicate dependencies cannot be resolved locally.
 	areDependenciesResolved := true
 	for depModule, declaredRefs := range depModuleToDeclaredRefs {
-		refStringToRef := make(map[string]bufmodule.ModuleRef)
+		refStringToRef := make(map[string]bufparse.Ref)
 		for _, ref := range declaredRefs {
-			// Add ref even if ref.Ref() is empty. Therefore, slicesext.ToValuesMap is not used.
+			// Add ref even if ref.Ref() is empty. Therefore, xslices.ToValuesMap is not used.
 			refStringToRef[ref.Ref()] = ref
 		}
 		// If there are both buf.build/foo/bar and buf.build/foo/bar:some_ref, the former will
@@ -360,7 +355,7 @@ func (m *migrator) buildBufYAMLAndBufLockFiles(
 		if len(refStringToRef) > 1 {
 			delete(refStringToRef, "")
 		}
-		depModuleToDeclaredRefs[depModule] = slicesext.MapValuesToSlice(refStringToRef)
+		depModuleToDeclaredRefs[depModule] = xslices.MapValuesToSlice(refStringToRef)
 		if len(refStringToRef) > 1 {
 			areDependenciesResolved = false
 		}
@@ -372,13 +367,13 @@ func (m *migrator) buildBufYAMLAndBufLockFiles(
 			// We could check,
 			commitIDToKey[lockEntry.CommitID()] = lockEntry
 		}
-		depModuleToLockEntries[depModule] = slicesext.MapValuesToSlice(commitIDToKey)
+		depModuleToLockEntries[depModule] = xslices.MapValuesToSlice(commitIDToKey)
 		if len(commitIDToKey) > 1 {
 			areDependenciesResolved = false
 		}
 	}
 	if areDependenciesResolved {
-		resolvedDeclaredRefs := make([]bufmodule.ModuleRef, 0, len(depModuleToDeclaredRefs))
+		resolvedDeclaredRefs := make([]bufparse.Ref, 0, len(depModuleToDeclaredRefs))
 		for _, depModuleRefs := range depModuleToDeclaredRefs {
 			// depModuleRefs is guaranteed to have length 1, because areDependenciesResolved is true.
 			resolvedDeclaredRefs = append(resolvedDeclaredRefs, depModuleRefs...)
@@ -386,7 +381,8 @@ func (m *migrator) buildBufYAMLAndBufLockFiles(
 		bufYAML, err := bufconfig.NewBufYAMLFile(
 			bufconfig.FileVersionV2,
 			migrateBuilder.moduleConfigs,
-			// TODO: If we ever need to migrate from a v2 to v3, we will need to handle PluginConfigs
+			// TODO: If we ever need to migrate from a v2 to v3, we will need to handle PluginConfigs and PolicyConfigs
+			nil,
 			nil,
 			resolvedDeclaredRefs,
 		)
@@ -406,6 +402,7 @@ func (m *migrator) buildBufYAMLAndBufLockFiles(
 			bufLock, err = bufconfig.NewBufLockFile(
 				bufconfig.FileVersionV2,
 				resolvedLockEntries,
+				nil,
 			)
 			if err != nil {
 				return nil, nil, err
@@ -434,7 +431,8 @@ func (m *migrator) buildBufYAMLAndBufLockFiles(
 	bufYAML, err := bufconfig.NewBufYAMLFile(
 		bufconfig.FileVersionV2,
 		migrateBuilder.moduleConfigs,
-		// TODO: If we ever need to migrate from a v2 to v3, we will need to handle PluginConfigs
+		// TODO: If we ever need to migrate from a v2 to v3, we will need to handle PluginConfigs and PolicyConfigs
+		nil,
 		nil,
 		resolvedDepModuleRefs,
 	)
@@ -450,6 +448,7 @@ func (m *migrator) buildBufYAMLAndBufLockFiles(
 		bufLock, err = bufconfig.NewBufLockFile(
 			bufconfig.FileVersionV2,
 			resolvedDepModuleKeys,
+			nil, // Plugins are not supported in v1.
 		)
 		if err != nil {
 			return nil, nil, err
@@ -460,15 +459,15 @@ func (m *migrator) buildBufYAMLAndBufLockFiles(
 
 func (m *migrator) getModuleToRefToCommit(
 	ctx context.Context,
-	moduleRefs []bufmodule.ModuleRef,
+	moduleRefs []bufparse.Ref,
 ) (map[string]map[string]bufmodule.Commit, error) {
 	// The module refs that are collected by migrateBuilder is across all modules being
 	// migrated, so there may be duplicates. ModuleKeyProvider errors on duplicate module
 	// refs because it is expensive to make multiple calls to resolve the same module ref,
 	// so we deduplicate the module refs we are passing here.
-	moduleRefs = slicesext.DeduplicateAny(
+	moduleRefs = xslices.DeduplicateAny(
 		moduleRefs,
-		func(moduleRef bufmodule.ModuleRef) string { return moduleRef.String() },
+		func(moduleRef bufparse.Ref) string { return moduleRef.String() },
 	)
 	moduleKeys, err := m.moduleKeyProvider.GetModuleKeysForModuleRefs(ctx, moduleRefs, bufmodule.DigestTypeB5)
 	if err != nil {
@@ -487,7 +486,7 @@ func (m *migrator) getModuleToRefToCommit(
 		// of GetModuleKeysForModuleRefs and GetCommitsForModuleKeys.
 		commit := commits[i]
 
-		moduleFullName := moduleRef.ModuleFullName()
+		moduleFullName := moduleRef.FullName()
 		if moduleToRefToCommit[moduleFullName.String()] == nil {
 			moduleToRefToCommit[moduleFullName.String()] = make(map[string]bufmodule.Commit)
 		}
@@ -504,7 +503,7 @@ func (m *migrator) getCommitIDToCommit(
 	// migrated, so there may be duplicates. CommitProvider errors on duplicate module
 	// keys because it is expensive to make multiple calls to resolve the same module key,
 	// so we deduplicate the module keys we are passing here.
-	moduleKeys = slicesext.DeduplicateAny(
+	moduleKeys = xslices.DeduplicateAny(
 		moduleKeys,
 		func(moduleKey bufmodule.ModuleKey) string { return moduleKey.String() },
 	)
@@ -514,7 +513,7 @@ func (m *migrator) getCommitIDToCommit(
 	}
 	commitIDToCommit := make(map[uuid.UUID]bufmodule.Commit, len(commits))
 	for _, commit := range commits {
-		// We don't know if these are unique, so we do not use slicesext.ToUniqueValuesMapError.
+		// We don't know if these are unique, so we do not use xslices.ToUniqueValuesMapError.
 		commitIDToCommit[commit.ModuleKey().CommitID()] = commit
 	}
 	return commitIDToCommit, nil
@@ -524,11 +523,11 @@ func (m *migrator) upgradeModuleKeysToB5(
 	ctx context.Context,
 	moduleKeys []bufmodule.ModuleKey,
 ) ([]bufmodule.ModuleKey, error) {
-	moduleKeys = slicesext.Copy(moduleKeys)
+	moduleKeys = slices.Clone(moduleKeys)
 
-	b4IndexedModuleKeys, err := slicesext.FilterError(
-		slicesext.ToIndexed(moduleKeys),
-		func(indexedModuleKey slicesext.Indexed[bufmodule.ModuleKey]) (bool, error) {
+	b4IndexedModuleKeys, err := xslices.FilterError(
+		xslices.ToIndexed(moduleKeys),
+		func(indexedModuleKey xslices.Indexed[bufmodule.ModuleKey]) (bool, error) {
 			digest, err := indexedModuleKey.Value.Digest()
 			if err != nil {
 				return false, err
@@ -544,11 +543,11 @@ func (m *migrator) upgradeModuleKeysToB5(
 		return moduleKeys, nil
 	}
 
-	commitKeys, err := slicesext.MapError(
+	commitKeys, err := xslices.MapError(
 		b4IndexedModuleKeys,
-		func(indexedModuleKey slicesext.Indexed[bufmodule.ModuleKey]) (bufmodule.CommitKey, error) {
+		func(indexedModuleKey xslices.Indexed[bufmodule.ModuleKey]) (bufmodule.CommitKey, error) {
 			return bufmodule.NewCommitKey(
-				indexedModuleKey.Value.ModuleFullName().Registry(),
+				indexedModuleKey.Value.FullName().Registry(),
 				indexedModuleKey.Value.CommitID(),
 				bufmodule.DigestTypeB5,
 			)
@@ -566,7 +565,7 @@ func (m *migrator) upgradeModuleKeysToB5(
 		moduleKeyIndex := b4IndexedModuleKeys[i].Index
 		existingModuleKey := moduleKeys[moduleKeyIndex]
 		newModuleKey, err := bufmodule.NewModuleKey(
-			existingModuleKey.ModuleFullName(),
+			existingModuleKey.FullName(),
 			existingModuleKey.CommitID(),
 			commit.ModuleKey().Digest,
 		)
@@ -581,10 +580,10 @@ func (m *migrator) upgradeModuleKeysToB5(
 func resolvedDeclaredAndLockedDependencies(
 	moduleToRefToCommit map[string]map[string]bufmodule.Commit,
 	commitIDToCommit map[uuid.UUID]bufmodule.Commit,
-	moduleFullNameToDeclaredRefs map[string][]bufmodule.ModuleRef,
+	moduleFullNameToDeclaredRefs map[string][]bufparse.Ref,
 	moduleFullNameToLockKeys map[string][]bufmodule.ModuleKey,
-) ([]bufmodule.ModuleRef, []bufmodule.ModuleKey, error) {
-	depModuleFullNameToResolvedRef := make(map[string]bufmodule.ModuleRef)
+) ([]bufparse.Ref, []bufmodule.ModuleKey, error) {
+	depFullNameToResolvedRef := make(map[string]bufparse.Ref)
 	for moduleFullName, refs := range moduleFullNameToDeclaredRefs {
 		var errs []error
 		// There are multiple pinned versions of the same dependency, we use the latest one.
@@ -601,13 +600,13 @@ func resolvedDeclaredAndLockedDependencies(
 			return iTime.After(jTime)
 		})
 		if len(errs) > 0 {
-			return nil, nil, multierr.Combine(errs...)
+			return nil, nil, errors.Join(errs...)
 		}
-		depModuleFullNameToResolvedRef[moduleFullName] = refs[0]
+		depFullNameToResolvedRef[moduleFullName] = refs[0]
 	}
 	resolvedDepModuleKeys := make([]bufmodule.ModuleKey, 0, len(moduleFullNameToLockKeys))
 	for moduleFullName, lockKeys := range moduleFullNameToLockKeys {
-		resolvedRef, ok := depModuleFullNameToResolvedRef[moduleFullName]
+		resolvedRef, ok := depFullNameToResolvedRef[moduleFullName]
 		if ok && resolvedRef.Ref() != "" {
 			// If we have already picked a pinned dependency ref for this dependency,
 			// we use that as the lock entry as well.
@@ -629,17 +628,17 @@ func resolvedDeclaredAndLockedDependencies(
 			return iTime.After(jTime)
 		})
 		if len(errs) > 0 {
-			return nil, nil, multierr.Combine(errs...)
+			return nil, nil, errors.Join(errs...)
 		}
 		resolvedDepModuleKeys = append(resolvedDepModuleKeys, lockKeys[0])
 	}
-	resolvedDeclaredDependencies := slicesext.MapValuesToSlice(depModuleFullNameToResolvedRef)
+	resolvedDeclaredDependencies := xslices.MapValuesToSlice(depFullNameToResolvedRef)
 	// Sort the resolved dependencies for deterministic results.
 	sort.Slice(resolvedDeclaredDependencies, func(i, j int) bool {
-		return resolvedDeclaredDependencies[i].ModuleFullName().String() < resolvedDeclaredDependencies[j].ModuleFullName().String()
+		return resolvedDeclaredDependencies[i].FullName().String() < resolvedDeclaredDependencies[j].FullName().String()
 	})
 	sort.Slice(resolvedDepModuleKeys, func(i, j int) bool {
-		return resolvedDepModuleKeys[i].ModuleFullName().String() < resolvedDepModuleKeys[j].ModuleFullName().String()
+		return resolvedDepModuleKeys[i].FullName().String() < resolvedDepModuleKeys[j].FullName().String()
 	})
 	return resolvedDeclaredDependencies, resolvedDepModuleKeys, nil
 }
@@ -647,13 +646,11 @@ func resolvedDeclaredAndLockedDependencies(
 func equivalentLintConfigInV2(
 	ctx context.Context,
 	logger *slog.Logger,
-	runner command.Runner,
 	lintConfig bufconfig.LintConfig,
 ) (bufconfig.LintConfig, error) {
 	equivalentCheckConfigV2, err := equivalentCheckConfigInV2(
 		ctx,
 		logger,
-		runner,
 		check.RuleTypeLint,
 		lintConfig,
 	)
@@ -674,13 +671,11 @@ func equivalentLintConfigInV2(
 func equivalentBreakingConfigInV2(
 	ctx context.Context,
 	logger *slog.Logger,
-	runner command.Runner,
 	breakingConfig bufconfig.BreakingConfig,
 ) (bufconfig.BreakingConfig, error) {
 	equivalentCheckConfigV2, err := equivalentCheckConfigInV2(
 		ctx,
 		logger,
-		runner,
 		check.RuleTypeBreaking,
 		breakingConfig,
 	)
@@ -698,13 +693,12 @@ func equivalentBreakingConfigInV2(
 func equivalentCheckConfigInV2(
 	ctx context.Context,
 	logger *slog.Logger,
-	runner command.Runner,
 	ruleType check.RuleType,
 	checkConfig bufconfig.CheckConfig,
 ) (bufconfig.CheckConfig, error) {
 	// No need for custom lint/breaking plugins since there's no plugins to migrate from <=v1.
 	// TODO: If we ever need v3, then we will have to deal with this.
-	client, err := bufcheck.NewClient(logger, bufcheck.NewRunnerProvider(runner, wasm.UnimplementedRuntime))
+	client, err := bufcheck.NewClient(logger)
 	if err != nil {
 		return nil, err
 	}
@@ -716,8 +710,8 @@ func equivalentCheckConfigInV2(
 	if err != nil {
 		return nil, err
 	}
-	expectedRules = slicesext.Filter(expectedRules, func(rule bufcheck.Rule) bool { return !rule.Deprecated() })
-	expectedIDs := slicesext.Map(
+	expectedRules = xslices.Filter(expectedRules, func(rule bufcheck.Rule) bool { return !rule.Deprecated() })
+	expectedIDs := xslices.Map(
 		expectedRules,
 		func(rule bufcheck.Rule) string {
 			return rule.ID()
@@ -741,37 +735,62 @@ func equivalentCheckConfigInV2(
 	if err != nil {
 		return nil, err
 	}
-	simplyTranslatedIDs := slicesext.Map(
+	simplyTranslatedIDs := xslices.Map(
 		simplyTranslatedRules,
 		func(rule bufcheck.Rule) string {
 			return rule.ID()
 		},
 	)
-	if slicesext.ElementsEqual(expectedIDs, simplyTranslatedIDs) {
+	if slices.Equal(expectedIDs, simplyTranslatedIDs) {
 		// If the simple translation is equivalent to before, use it.
 		return simplyTranslatedCheckConfig, nil
 	}
 	// Otherwise, find what's missing and what's extra.
-	expectedIDsMap := slicesext.ToStructMap(expectedIDs)
-	simplyTranslatedIDsMap := slicesext.ToStructMap(simplyTranslatedIDs)
-	missingIDs := slicesext.Filter(
+	expectedIDsMap := xslices.ToStructMap(expectedIDs)
+	simplyTranslatedIDsMap := xslices.ToStructMap(simplyTranslatedIDs)
+	missingIDs := xslices.Filter(
 		expectedIDs,
 		func(expectedID string) bool {
 			_, ok := simplyTranslatedIDsMap[expectedID]
 			return !ok
 		},
 	)
-	extraIDs := slicesext.Filter(
+	extraIDs := xslices.Filter(
 		simplyTranslatedIDs,
 		func(simplyTranslatedID string) bool {
 			_, ok := expectedIDsMap[simplyTranslatedID]
 			return !ok
 		},
 	)
+	// Filter remaining rules to match the V2 rule set. Any other rules are ignored.
+	// Theres no additional rules from plugins as plugins didn't exist before v2.
+	validV2IDsMap := make(map[string]struct{})
+	for _, ruleSpec := range bufcheckserver.V2Spec.Rules {
+		if ruleSpec.Type == ruleType {
+			validV2IDsMap[ruleSpec.ID] = struct{}{}
+		}
+	}
+	for _, categorySpec := range bufcheckserver.V2Spec.Categories {
+		validV2IDsMap[categorySpec.ID] = struct{}{}
+	}
+	useIDsAndCategories := xslices.Filter(
+		append(simplyTranslatedCheckConfig.UseIDsAndCategories(), missingIDs...),
+		func(ruleID string) bool {
+			_, ok := validV2IDsMap[ruleID]
+			return ok
+		},
+	)
+	exceptIDsAndCategories := xslices.Filter(
+		append(simplyTranslatedCheckConfig.ExceptIDsAndCategories(), extraIDs...),
+		func(ruleID string) bool {
+			_, ok := validV2IDsMap[ruleID]
+			return ok
+		},
+	)
 	return bufconfig.NewEnabledCheckConfig(
 		bufconfig.FileVersionV2,
-		append(simplyTranslatedCheckConfig.UseIDsAndCategories(), missingIDs...),
-		append(simplyTranslatedCheckConfig.ExceptIDsAndCategories(), extraIDs...),
+		useIDsAndCategories,
+		exceptIDsAndCategories,
 		simplyTranslatedCheckConfig.IgnorePaths(),
 		simplyTranslatedCheckConfig.IgnoreIDOrCategoryToPaths(),
 		simplyTranslatedCheckConfig.DisableBuiltin(),
