@@ -1,4 +1,4 @@
-// Copyright 2020-2024 Buf Technologies, Inc.
+// Copyright 2020-2025 Buf Technologies, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -21,14 +21,16 @@ import (
 	"io/fs"
 	"log/slog"
 
+	"buf.build/go/standard/xlog/xslog"
+	"buf.build/go/standard/xslices"
+	"buf.build/go/standard/xstrings"
 	"github.com/bufbuild/buf/private/buf/buftarget"
 	"github.com/bufbuild/buf/private/bufpkg/bufconfig"
 	"github.com/bufbuild/buf/private/bufpkg/bufmodule"
+	"github.com/bufbuild/buf/private/bufpkg/bufparse"
+	"github.com/bufbuild/buf/private/bufpkg/bufplugin"
 	"github.com/bufbuild/buf/private/pkg/normalpath"
-	"github.com/bufbuild/buf/private/pkg/slicesext"
-	"github.com/bufbuild/buf/private/pkg/slogext"
 	"github.com/bufbuild/buf/private/pkg/storage"
-	"github.com/bufbuild/buf/private/pkg/stringutil"
 	"github.com/bufbuild/buf/private/pkg/syserror"
 	"github.com/google/uuid"
 )
@@ -76,12 +78,14 @@ func NewWorkspaceProvider(
 	graphProvider bufmodule.GraphProvider,
 	moduleDataProvider bufmodule.ModuleDataProvider,
 	commitProvider bufmodule.CommitProvider,
+	pluginKeyProvider bufplugin.PluginKeyProvider,
 ) WorkspaceProvider {
 	return newWorkspaceProvider(
 		logger,
 		graphProvider,
 		moduleDataProvider,
 		commitProvider,
+		pluginKeyProvider,
 	)
 }
 
@@ -92,6 +96,10 @@ type workspaceProvider struct {
 	graphProvider      bufmodule.GraphProvider
 	moduleDataProvider bufmodule.ModuleDataProvider
 	commitProvider     bufmodule.CommitProvider
+
+	// pluginKeyProvider is only used for getting remote plugin keys for a single module
+	// when an override is specified.
+	pluginKeyProvider bufplugin.PluginKeyProvider
 }
 
 func newWorkspaceProvider(
@@ -99,12 +107,14 @@ func newWorkspaceProvider(
 	graphProvider bufmodule.GraphProvider,
 	moduleDataProvider bufmodule.ModuleDataProvider,
 	commitProvider bufmodule.CommitProvider,
+	pluginKeyProvider bufplugin.PluginKeyProvider,
 ) *workspaceProvider {
 	return &workspaceProvider{
 		logger:             logger,
 		graphProvider:      graphProvider,
 		moduleDataProvider: moduleDataProvider,
 		commitProvider:     commitProvider,
+		pluginKeyProvider:  pluginKeyProvider,
 	}
 }
 
@@ -113,7 +123,7 @@ func (w *workspaceProvider) GetWorkspaceForModuleKey(
 	moduleKey bufmodule.ModuleKey,
 	options ...WorkspaceModuleKeyOption,
 ) (Workspace, error) {
-	defer slogext.DebugProfile(w.logger)()
+	defer xslog.DebugProfile(w.logger)()
 
 	config, err := newWorkspaceModuleKeyConfig(options)
 	if err != nil {
@@ -135,8 +145,11 @@ func (w *workspaceProvider) GetWorkspaceForModuleKey(
 	targetModuleConfig := bufconfig.DefaultModuleConfigV1
 	// By default, there will be no plugin configs, however, similar to the lint and breaking
 	// configs, there may be an override, in which case, we need to populate the plugin configs
-	// from the override.
-	var pluginConfigs []bufconfig.PluginConfig
+	// from the override. Any remote plugin refs will be resolved by the pluginKeyProvider.
+	var (
+		pluginConfigs    []bufconfig.PluginConfig
+		remotePluginKeys []bufplugin.PluginKey
+	)
 	if config.configOverride != "" {
 		bufYAMLFile, err := bufconfig.GetBufYAMLFileForOverride(config.configOverride)
 		if err != nil {
@@ -149,7 +162,7 @@ func (w *workspaceProvider) GetWorkspaceForModuleKey(
 		case 1:
 			// If we have a single ModuleConfig, we assume that regardless of whether or not
 			// This ModuleConfig has a name, that this is what the user intends to associate
-			// with the tqrget module. This also handles the v1 case - v1 buf.yamls will always
+			// with the target module. This also handles the v1 case - v1 buf.yamls will always
 			// only have a single ModuleConfig, and it was expected pre-refactor that regardless
 			// of if the ModuleConfig had a name associated with it or not, the lint and breaking
 			// config that came from it would be associated.
@@ -158,19 +171,40 @@ func (w *workspaceProvider) GetWorkspaceForModuleKey(
 			// If we have more than one ModuleConfig, find the ModuleConfig that matches the
 			// name from the ModuleKey. If none is found, just fall back to the default (ie do nothing here).
 			for _, moduleConfig := range moduleConfigs {
-				moduleFullName := moduleConfig.ModuleFullName()
+				moduleFullName := moduleConfig.FullName()
 				if moduleFullName == nil {
 					continue
 				}
-				if bufmodule.ModuleFullNameEqual(moduleFullName, moduleKey.ModuleFullName()) {
+				if bufparse.FullNameEqual(moduleFullName, moduleKey.FullName()) {
 					targetModuleConfig = moduleConfig
-					// We know that the ModuleConfigs are unique by ModuleFullName.
+					// We know that the ModuleConfigs are unique by FullName.
 					break
 				}
 			}
 		}
 		if bufYAMLFile.FileVersion() == bufconfig.FileVersionV2 {
 			pluginConfigs = bufYAMLFile.PluginConfigs()
+			// To support remote plugins when using a config override, we need to resolve the remote
+			// Refs to PluginKeys. We use the pluginKeyProvider to resolve any remote plugin Refs.
+			remotePluginRefs := xslices.Filter(
+				xslices.Map(pluginConfigs, func(pluginConfig bufconfig.PluginConfig) bufparse.Ref {
+					return pluginConfig.Ref()
+				}),
+				func(ref bufparse.Ref) bool {
+					return ref != nil
+				},
+			)
+			if len(remotePluginRefs) > 0 {
+				var err error
+				remotePluginKeys, err = w.pluginKeyProvider.GetPluginKeysForPluginRefs(
+					ctx,
+					remotePluginRefs,
+					bufplugin.DigestTypeP1,
+				)
+				if err != nil {
+					return nil, err
+				}
+			}
 		}
 	}
 
@@ -193,7 +227,7 @@ func (w *workspaceProvider) GetWorkspaceForModuleKey(
 	opaqueIDToLintConfig := make(map[string]bufconfig.LintConfig)
 	opaqueIDToBreakingConfig := make(map[string]bufconfig.BreakingConfig)
 	for _, module := range moduleSet.Modules() {
-		if bufmodule.ModuleFullNameEqual(module.ModuleFullName(), moduleKey.ModuleFullName()) {
+		if bufparse.FullNameEqual(module.FullName(), moduleKey.FullName()) {
 			// Set the lint and breaking config for the single targeted Module.
 			opaqueIDToLintConfig[module.OpaqueID()] = targetModuleConfig.LintConfig()
 			opaqueIDToBreakingConfig[module.OpaqueID()] = targetModuleConfig.BreakingConfig()
@@ -208,18 +242,18 @@ func (w *workspaceProvider) GetWorkspaceForModuleKey(
 		opaqueIDToLintConfig,
 		opaqueIDToBreakingConfig,
 		pluginConfigs,
+		remotePluginKeys,
 		nil,
 		false,
 	), nil
 }
 
-func (w *workspaceProvider) GetWorkspaceForBucket(
+func (w *workspaceProvider) getWorkspaceTargetingForBucket(
 	ctx context.Context,
 	bucket storage.ReadBucket,
 	bucketTargeting buftarget.BucketTargeting,
 	options ...WorkspaceBucketOption,
-) (Workspace, error) {
-	defer slogext.DebugProfile(w.logger)()
+) (*workspaceTargeting, error) {
 	config, err := newWorkspaceBucketConfig(options)
 	if err != nil {
 		return nil, err
@@ -231,7 +265,7 @@ func (w *workspaceProvider) GetWorkspaceForBucket(
 			return nil, err
 		}
 	}
-	workspaceTargeting, err := newWorkspaceTargeting(
+	return newWorkspaceTargeting(
 		ctx,
 		w.logger,
 		config,
@@ -240,6 +274,21 @@ func (w *workspaceProvider) GetWorkspaceForBucket(
 		overrideBufYAMLFile,
 		config.ignoreAndDisallowV1BufWorkYAMLs,
 	)
+}
+
+func (w *workspaceProvider) GetWorkspaceForBucket(
+	ctx context.Context,
+	bucket storage.ReadBucket,
+	bucketTargeting buftarget.BucketTargeting,
+	options ...WorkspaceBucketOption,
+) (Workspace, error) {
+	defer xslog.DebugProfile(w.logger)()
+	workspaceTargeting, err := w.getWorkspaceTargetingForBucket(
+		ctx,
+		bucket,
+		bucketTargeting,
+		options...,
+	)
 	if err != nil {
 		return nil, err
 	}
@@ -330,7 +379,7 @@ func (w *workspaceProvider) getWorkspaceForBucketAndModuleDirPathsV1Beta1OrV1(
 			mappedModuleBucket,
 			moduleBucketAndTargeting.bucketID,
 			moduleTargeting.isTargetModule,
-			bufmodule.LocalModuleWithModuleFullName(moduleConfig.ModuleFullName()),
+			bufmodule.LocalModuleWithFullName(moduleConfig.FullName()),
 			bufmodule.LocalModuleWithTargetPaths(
 				moduleTargeting.moduleTargetPaths,
 				moduleTargeting.moduleTargetExcludePaths,
@@ -357,7 +406,8 @@ func (w *workspaceProvider) getWorkspaceForBucketAndModuleDirPathsV1Beta1OrV1(
 	return w.getWorkspaceForBucketModuleSet(
 		moduleSet,
 		v1WorkspaceTargeting.bucketIDToModuleConfig,
-		nil,
+		nil, // No PluginConfigs for v1
+		nil, // No remote PluginKeys for v1
 		v1WorkspaceTargeting.allConfiguredDepModuleRefs,
 		false,
 	)
@@ -369,6 +419,7 @@ func (w *workspaceProvider) getWorkspaceForBucketBufYAMLV2(
 	v2Targeting *v2Targeting,
 ) (*workspace, error) {
 	moduleSetBuilder := bufmodule.NewModuleSetBuilder(ctx, w.logger, w.moduleDataProvider, w.commitProvider)
+	var remotePluginKeys []bufplugin.PluginKey
 	bufLockFile, err := bufconfig.GetBufLockFileForPrefix(
 		ctx,
 		bucket,
@@ -397,6 +448,7 @@ func (w *workspaceProvider) getWorkspaceForBucketBufYAMLV2(
 				false,
 			)
 		}
+		remotePluginKeys = bufLockFile.RemotePluginKeys()
 	}
 	// Only check for duplicate module description in v2, which would be an user error, i.e.
 	// This is not a system error:
@@ -434,7 +486,7 @@ func (w *workspaceProvider) getWorkspaceForBucketBufYAMLV2(
 			mappedModuleBucket,
 			moduleBucketAndTargeting.bucketID,
 			moduleTargeting.isTargetModule,
-			bufmodule.LocalModuleWithModuleFullName(moduleConfig.ModuleFullName()),
+			bufmodule.LocalModuleWithFullName(moduleConfig.FullName()),
 			bufmodule.LocalModuleWithTargetPaths(
 				moduleTargeting.moduleTargetPaths,
 				moduleTargeting.moduleTargetExcludePaths,
@@ -454,6 +506,7 @@ func (w *workspaceProvider) getWorkspaceForBucketBufYAMLV2(
 		moduleSet,
 		v2Targeting.bucketIDToModuleConfig,
 		v2Targeting.bufYAMLFile.PluginConfigs(),
+		remotePluginKeys,
 		v2Targeting.bufYAMLFile.ConfiguredDepModuleRefs(),
 		true,
 	)
@@ -464,8 +517,9 @@ func (w *workspaceProvider) getWorkspaceForBucketModuleSet(
 	moduleSet bufmodule.ModuleSet,
 	bucketIDToModuleConfig map[string]bufconfig.ModuleConfig,
 	pluginConfigs []bufconfig.PluginConfig,
-	// Expected to already be unique by ModuleFullName.
-	configuredDepModuleRefs []bufmodule.ModuleRef,
+	remotePluginKeys []bufplugin.PluginKey,
+	// Expected to already be unique by FullName.
+	configuredDepModuleRefs []bufparse.Ref,
 	isV2 bool,
 ) (*workspace, error) {
 	opaqueIDToLintConfig := make(map[string]bufconfig.LintConfig)
@@ -489,6 +543,7 @@ func (w *workspaceProvider) getWorkspaceForBucketModuleSet(
 		opaqueIDToLintConfig,
 		opaqueIDToBreakingConfig,
 		pluginConfigs,
+		remotePluginKeys,
 		configuredDepModuleRefs,
 		isV2,
 	), nil
@@ -507,7 +562,7 @@ func getLocalModuleDescription(pathDescription string, moduleConfig bufconfig.Mo
 	description := fmt.Sprintf("path: %q", pathDescription)
 	moduleDirPath := moduleConfig.DirPath()
 	relIncludePaths := moduleConfig.RootToIncludes()["."]
-	includePaths := slicesext.Map(relIncludePaths, func(relInclude string) string {
+	includePaths := xslices.Map(relIncludePaths, func(relInclude string) string {
 		return normalpath.Join(moduleDirPath, relInclude)
 	})
 	switch len(includePaths) {
@@ -515,10 +570,10 @@ func getLocalModuleDescription(pathDescription string, moduleConfig bufconfig.Mo
 	case 1:
 		description = fmt.Sprintf("%s, includes: %q", description, includePaths[0])
 	default:
-		description = fmt.Sprintf("%s, includes: [%s]", description, stringutil.JoinSliceQuoted(includePaths, ", "))
+		description = fmt.Sprintf("%s, includes: [%s]", description, xstrings.JoinSliceQuoted(includePaths, ", "))
 	}
 	relExcludePaths := moduleConfig.RootToExcludes()["."]
-	excludePaths := slicesext.Map(relExcludePaths, func(relInclude string) string {
+	excludePaths := xslices.Map(relExcludePaths, func(relInclude string) string {
 		return normalpath.Join(moduleDirPath, relInclude)
 	})
 	switch len(excludePaths) {
@@ -526,7 +581,7 @@ func getLocalModuleDescription(pathDescription string, moduleConfig bufconfig.Mo
 	case 1:
 		description = fmt.Sprintf("%s, excludes: %q", description, excludePaths[0])
 	default:
-		description = fmt.Sprintf("%s, excludes: [%s]", description, stringutil.JoinSliceQuoted(excludePaths, ", "))
+		description = fmt.Sprintf("%s, excludes: [%s]", description, xstrings.JoinSliceQuoted(excludePaths, ", "))
 	}
 	return description
 }
