@@ -1,4 +1,4 @@
-// Copyright 2020-2024 Buf Technologies, Inc.
+// Copyright 2020-2025 Buf Technologies, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -22,11 +22,12 @@ import (
 	"log/slog"
 	"path/filepath"
 
+	"buf.build/go/standard/xslices"
 	"github.com/bufbuild/buf/private/buf/buftarget"
 	"github.com/bufbuild/buf/private/bufpkg/bufconfig"
 	"github.com/bufbuild/buf/private/bufpkg/bufmodule"
+	"github.com/bufbuild/buf/private/bufpkg/bufparse"
 	"github.com/bufbuild/buf/private/pkg/normalpath"
-	"github.com/bufbuild/buf/private/pkg/slicesext"
 	"github.com/bufbuild/buf/private/pkg/storage"
 	"github.com/bufbuild/buf/private/pkg/syserror"
 )
@@ -53,7 +54,7 @@ type workspaceTargeting struct {
 type v1Targeting struct {
 	bucketIDToModuleConfig     map[string]bufconfig.ModuleConfig
 	moduleBucketsAndTargeting  []*moduleBucketAndModuleTargeting
-	allConfiguredDepModuleRefs []bufmodule.ModuleRef
+	allConfiguredDepModuleRefs []bufparse.Ref
 }
 
 type v2Targeting struct {
@@ -193,7 +194,7 @@ func v2WorkspaceTargeting(
 	bufYAMLFile bufconfig.BufYAMLFile,
 	// If true and if a workspace module does not have a license/doc at its moduleDirPath,
 	// use the license/doc respectively at the workspace root for this module.
-	useWorkspaceLicenseDocIfNotFoundAtMoudle bool,
+	useWorkspaceLicenseDocIfNotFoundAtModule bool,
 ) (*workspaceTargeting, error) {
 	// We keep track of if any module was tentatively targeted, and then actually targeted via
 	// the paths flags. We use this pre-building of the ModuleSet to see if the --path and
@@ -230,7 +231,7 @@ func v2WorkspaceTargeting(
 		isTentativelyTargetModule := normalpath.EqualsOrContainsPath(bucketTargeting.SubDirPath(), moduleDirPath, normalpath.Relative)
 		// We ignore this check for proto file refs, since the input is considered the directory
 		// of the proto file reference, which is unlikely to contain a module in its entirety.
-		// In the future, it would be nice to handle this more elegently.
+		// In the future, it would be nice to handle this more elegantly.
 		if config.protoFileTargetPath != "" {
 			isTentativelyTargetModule = true
 		}
@@ -245,7 +246,7 @@ func v2WorkspaceTargeting(
 			moduleDirPath,
 			moduleConfig,
 			isTentativelyTargetModule,
-			useWorkspaceLicenseDocIfNotFoundAtMoudle,
+			useWorkspaceLicenseDocIfNotFoundAtModule,
 		)
 		if err != nil {
 			return nil, err
@@ -296,7 +297,7 @@ func v1WorkspaceTargeting(
 	// directories, and this is a system error - this should be verified before we reach this function.
 	var hadIsTentativelyTargetModule bool
 	var hadIsTargetModule bool
-	var allConfiguredDepModuleRefs []bufmodule.ModuleRef
+	var allConfiguredDepModuleRefs []bufparse.Ref
 	bucketIDToModuleConfig := make(map[string]bufconfig.ModuleConfig)
 	// We use this to detect different refs across different files.
 	moduleFullNameStringToConfiguredDepModuleRefString := make(map[string]string)
@@ -312,15 +313,15 @@ func v1WorkspaceTargeting(
 			return nil, err
 		}
 		for _, configuredDepModuleRef := range configuredDepModuleRefs {
-			moduleFullNameString := configuredDepModuleRef.ModuleFullName().String()
+			moduleFullNameString := configuredDepModuleRef.FullName().String()
 			configuredDepModuleRefString := configuredDepModuleRef.String()
 			existingConfiguredDepModuleRefString, ok := moduleFullNameStringToConfiguredDepModuleRefString[moduleFullNameString]
 			if !ok {
-				// We haven't encountered a ModuleRef with this ModuleFullName yet, add it.
+				// We haven't encountered a ModuleRef with this FullName yet, add it.
 				allConfiguredDepModuleRefs = append(allConfiguredDepModuleRefs, configuredDepModuleRef)
 				moduleFullNameStringToConfiguredDepModuleRefString[moduleFullNameString] = configuredDepModuleRefString
 			} else if configuredDepModuleRefString != existingConfiguredDepModuleRefString {
-				// We encountered the same ModuleRef by ModuleFullName, but with a different Ref.
+				// We encountered the same ModuleRef by FullName, but with a different Ref.
 				return nil, fmt.Errorf("found different refs for the same module within buf.yaml deps in the workspace: %s %s", configuredDepModuleRefString, existingConfiguredDepModuleRefString)
 			}
 		}
@@ -337,7 +338,7 @@ func v1WorkspaceTargeting(
 		isTentativelyTargetModule := normalpath.EqualsOrContainsPath(bucketTargeting.SubDirPath(), moduleDirPath, normalpath.Relative)
 		// We ignore this check for proto file refs, since the input is considered the directory
 		// of the proto file reference, which is unlikely to contain a module in its entirety.
-		// In the future, it would be nice to handle this more elegently.
+		// In the future, it would be nice to handle this more elegantly.
 		if config.protoFileTargetPath != "" {
 			isTentativelyTargetModule = true
 		}
@@ -568,7 +569,7 @@ func getMappedModuleBucketAndModuleTargeting(
 	isTargetModule bool,
 	// If true and if a workspace module does not have a license/doc at its moduleDirPath,
 	// use the license/doc respectively at the workspace root for this module.
-	useWorkspaceLicenseDocIfNotFoundAtMoudle bool,
+	useWorkspaceLicenseDocIfNotFoundAtModule bool,
 ) (storage.ReadBucket, *moduleTargeting, error) {
 	moduleBucket := storage.MapReadBucket(
 		workspaceBucket,
@@ -644,7 +645,7 @@ func getMappedModuleBucketAndModuleTargeting(
 	if err != nil {
 		return nil, nil, err
 	}
-	if useWorkspaceLicenseDocIfNotFoundAtMoudle {
+	if useWorkspaceLicenseDocIfNotFoundAtModule {
 		isModuleDocBucketEmpty, err := storage.IsEmpty(ctx, docStorageReadBucket, "")
 		if err != nil {
 			return nil, nil, err
@@ -682,7 +683,7 @@ func getMappedModuleBucketAndModuleTargeting(
 	mappedModuleBucket := storage.MultiReadBucket(rootBuckets...)
 	moduleTargeting, err := newModuleTargeting(
 		moduleDirPath,
-		slicesext.MapKeysToSlice(rootToExcludes),
+		xslices.MapKeysToSlice(rootToExcludes),
 		bucketTargeting,
 		config,
 		isTargetModule,
@@ -698,7 +699,7 @@ func getModuleConfigAndConfiguredDepModuleRefsV1Beta1OrV1(
 	bucket storage.ReadBucket,
 	moduleDirPath string,
 	overrideBufYAMLFile bufconfig.BufYAMLFile,
-) (bufconfig.ModuleConfig, []bufmodule.ModuleRef, error) {
+) (bufconfig.ModuleConfig, []bufparse.Ref, error) {
 	var bufYAMLFile bufconfig.BufYAMLFile
 	var err error
 	if overrideBufYAMLFile != nil {
@@ -832,12 +833,12 @@ func checkForOverlap(
 //
 // v1 does not need to call a function like this because bucketIDs are just their module roots relative to the workspace root, which are unique.
 func bucketIDsForModuleConfigsV2(moduleConfigs []bufconfig.ModuleConfig) []string {
-	moduleDirPaths := slicesext.Map(moduleConfigs, bufconfig.ModuleConfig.DirPath)
+	moduleDirPaths := xslices.Map(moduleConfigs, bufconfig.ModuleConfig.DirPath)
 	// In a v2 bufYAMLFile, multiple module configs may have the same DirPath, but we still want to
 	// make sure each local module has a unique BucketID, which means we cannot use their DirPaths as
 	// BucketIDs directly. Instead, we append an index (1-indexed) to each DirPath to deduplicate, and
 	// each module's bucketID becomes "<path>[index]", except for the first one does not need the index
-	// and its bucketID is stil "<path>".
+	// and its bucketID is still "<path>".
 	// As an example, bucketIDs are shown for modules in the buf.yaml below:
 	// ...
 	// modules:
@@ -855,7 +856,7 @@ func bucketIDsForModuleConfigsV2(moduleConfigs []bufconfig.ModuleConfig) []strin
 	// [bar, bar, bar, foo, foo, foo, new].
 	//                       ^
 	bucketIDs := bucketIDsForDirPaths(moduleDirPaths, false)
-	if len(slicesext.Duplicates(bucketIDs)) == 0 {
+	if len(xslices.Duplicates(bucketIDs)) == 0 {
 		// This approach does not produce duplicate bucketIDs in the result most of the time, we return
 		// the bucketIDs if we don't detect any duplicates and it gives us the nice property that for
 		// 99% of the v2 workspaces, each module's bucketID is its DirPath.
