@@ -24,12 +24,11 @@ import (
 	"io"
 	"net"
 
+	"buf.build/go/app/appcmd"
+	"buf.build/go/app/appext"
+	"buf.build/go/standard/xio"
 	"github.com/bufbuild/buf/private/buf/bufcli"
 	"github.com/bufbuild/buf/private/buf/buflsp"
-	"github.com/bufbuild/buf/private/pkg/app/appcmd"
-	"github.com/bufbuild/buf/private/pkg/app/appext"
-	"github.com/bufbuild/buf/private/pkg/ioext"
-	"github.com/bufbuild/buf/private/pkg/wasm"
 	"github.com/spf13/pflag"
 	"go.lsp.dev/jsonrpc2"
 )
@@ -101,11 +100,7 @@ func run(
 		return err
 	}
 
-	wasmRuntimeCacheDir, err := bufcli.CreateWasmRuntimeCacheDir(container)
-	if err != nil {
-		return err
-	}
-	wasmRuntime, err := wasm.NewRuntime(ctx, wasm.WithLocalCacheDir(wasmRuntimeCacheDir))
+	wasmRuntime, err := bufcli.NewWasmRuntime(ctx, container)
 	if err != nil {
 		return err
 	}
@@ -135,10 +130,10 @@ func dial(container appext.Container, flags *flags) (io.ReadWriteCloser, error)
 
 	default:
 		// Fall back to stdio by default.
-		return ioext.CompositeReadWriteCloser(
+		return xio.CompositeReadWriteCloser(
 			container.Stdin(),
 			container.Stdout(),
-			ioext.NopCloser,
+			xio.NopCloser,
 		), nil
 	}
 }
