@@ -1,4 +1,4 @@
-// Copyright 2020-2024 Buf Technologies, Inc.
+// Copyright 2020-2025 Buf Technologies, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -24,6 +24,9 @@ import (
 	"os"
 	"strings"
 
+	"buf.build/go/app/appcmd"
+	"buf.build/go/app/appext"
+	"buf.build/go/standard/xstrings"
 	"connectrpc.com/connect"
 	"github.com/bufbuild/buf/private/buf/bufcli"
 	"github.com/bufbuild/buf/private/buf/bufprint"
@@ -32,15 +35,12 @@ import (
 	"github.com/bufbuild/buf/private/bufpkg/bufremoteplugin/bufremoteplugindocker"
 	"github.com/bufbuild/buf/private/gen/proto/connect/buf/alpha/registry/v1alpha1/registryv1alpha1connect"
 	registryv1alpha1 "github.com/bufbuild/buf/private/gen/proto/go/buf/alpha/registry/v1alpha1"
-	"github.com/bufbuild/buf/private/pkg/app/appcmd"
-	"github.com/bufbuild/buf/private/pkg/app/appext"
 	"github.com/bufbuild/buf/private/pkg/connectclient"
 	"github.com/bufbuild/buf/private/pkg/netext"
 	"github.com/bufbuild/buf/private/pkg/netrc"
 	"github.com/bufbuild/buf/private/pkg/storage"
 	"github.com/bufbuild/buf/private/pkg/storage/storagearchive"
 	"github.com/bufbuild/buf/private/pkg/storage/storageos"
-	"github.com/bufbuild/buf/private/pkg/stringutil"
 	"github.com/bufbuild/buf/private/pkg/syserror"
 	"github.com/google/go-containerregistry/pkg/authn"
 	"github.com/google/go-containerregistry/pkg/name"
@@ -48,7 +48,6 @@ import (
 	"github.com/google/go-containerregistry/pkg/v1/remote"
 	"github.com/google/go-containerregistry/pkg/v1/remote/transport"
 	"github.com/spf13/pflag"
-	"go.uber.org/multierr"
 )
 
 const (
@@ -62,7 +61,7 @@ const (
 	privateVisibility = "private"
 )
 
-var allVisibiltyStrings = []string{
+var allVisibilityStrings = []string{
 	publicVisibility,
 	privateVisibility,
 }
@@ -123,7 +122,7 @@ func (f *flags) Bind(flagSet *pflag.FlagSet) {
 		&f.Visibility,
 		visibilityFlagName,
 		"",
-		fmt.Sprintf(`The plugin's visibility setting. Must be one of %s`, stringutil.SliceToString(allVisibiltyStrings)),
+		fmt.Sprintf(`The plugin's visibility setting. Must be one of %s`, xstrings.SliceToString(allVisibilityStrings)),
 	)
 	_ = appcmd.MarkFlagRequired(flagSet, visibilityFlagName)
 }
@@ -161,7 +160,7 @@ func run(
 		}
 		defer func() {
 			if err := os.RemoveAll(tmpDir); !os.IsNotExist(err) {
-				retErr = multierr.Append(retErr, err)
+				retErr = errors.Join(retErr, err)
 			}
 		}()
 		sourceBucket, err = storageProvider.NewReadWriteBucket(tmpDir)
@@ -198,7 +197,7 @@ func run(
 	}
 	defer func() {
 		if err := client.Close(); err != nil {
-			retErr = multierr.Append(retErr, fmt.Errorf("docker client close error: %w", err))
+			retErr = errors.Join(retErr, fmt.Errorf("docker client close error: %w", err))
 		}
 	}()
 	var imageID string
@@ -219,7 +218,7 @@ func run(
 		}
 		defer func() {
 			if err := image.Close(); err != nil && !errors.Is(err, storage.ErrClosed) {
-				retErr = multierr.Append(retErr, fmt.Errorf("docker image close error: %w", err))
+				retErr = errors.Join(retErr, fmt.Errorf("docker image close error: %w", err))
 			}
 		}()
 		imageID = loadResponse.ImageID
@@ -240,12 +239,12 @@ func run(
 	latestPluginResp, err := service.GetLatestCuratedPlugin(
 		ctx,
 		connect.NewRequest(
-			&registryv1alpha1.GetLatestCuratedPluginRequest{
+			registryv1alpha1.GetLatestCuratedPluginRequest_builder{
 				Owner:    pluginConfig.Name.Owner(),
 				Name:     pluginConfig.Name.Plugin(),
 				Version:  pluginConfig.PluginVersion,
 				Revision: 0, // get latest revision for the plugin version.
-			},
+			}.Build(),
 		),
 	)
 	var currentImageDigest string
@@ -256,8 +255,8 @@ func run(
 		}
 		nextRevision = 1
 	} else {
-		nextRevision = latestPluginResp.Msg.Plugin.Revision + 1
-		currentImageDigest = latestPluginResp.Msg.Plugin.ContainerImageDigest
+		nextRevision = latestPluginResp.Msg.GetPlugin().GetRevision() + 1
+		currentImageDigest = latestPluginResp.Msg.GetPlugin().GetContainerImageDigest()
 	}
 	machine, err := netrc.GetMachineForName(container, pluginConfig.Name.Remote())
 	if err != nil {
@@ -308,9 +307,9 @@ func run(
 			slog.String("name", pluginConfig.Name.IdentityString()),
 			slog.String("digest", plugin.ContainerImageDigest()),
 		)
-		curatedPlugin = latestPluginResp.Msg.Plugin
+		curatedPlugin = latestPluginResp.Msg.GetPlugin()
 	} else {
-		curatedPlugin = createPluginResp.Msg.Configuration
+		curatedPlugin = createPluginResp.Msg.GetConfiguration()
 	}
 	return bufprint.NewCuratedPluginPrinter(container.Stdout()).PrintCuratedPlugin(ctx, format, curatedPlugin)
 }
@@ -329,7 +328,7 @@ func createCuratedPluginRequest(
 	if err != nil {
 		return nil, err
 	}
-	return &registryv1alpha1.CreateCuratedPluginRequest{
+	return registryv1alpha1.CreateCuratedPluginRequest_builder{
 		Owner:                pluginConfig.Name.Owner(),
 		Name:                 pluginConfig.Name.Plugin(),
 		RegistryType:         bufremoteplugin.PluginToProtoPluginRegistryType(plugin),
@@ -345,7 +344,8 @@ func createCuratedPluginRequest(
 		LicenseUrl:           pluginConfig.LicenseURL,
 		Visibility:           visibility,
 		IntegrationGuideUrl:  pluginConfig.IntegrationGuideURL,
-	}, nil
+		Deprecated:           pluginConfig.Deprecated,
+	}.Build(), nil
 }
 
 func pushImage(
@@ -364,7 +364,7 @@ func pushImage(
 	// After we're done publishing the image, we delete it to not leave a lot of images left behind.
 	defer func() {
 		if _, err := client.Delete(ctx, createdImage); err != nil {
-			retErr = multierr.Append(retErr, fmt.Errorf("failed to delete image %q", createdImage))
+			retErr = errors.Join(retErr, fmt.Errorf("failed to delete image %q", createdImage))
 		}
 	}()
 	pushResponse, err := client.Push(ctx, createdImage, authConfig)
@@ -515,7 +515,7 @@ func unzipPluginToSourceBucket(ctx context.Context, pluginZip string, size int64
 	}
 	defer func() {
 		if err := f.Close(); err != nil {
-			retErr = multierr.Append(retErr, fmt.Errorf("plugin zip close error: %w", err))
+			retErr = errors.Join(retErr, fmt.Errorf("plugin zip close error: %w", err))
 		}
 	}()
 	return storagearchive.Unzip(ctx, f, size, bucket)
@@ -536,7 +536,7 @@ func visibilityFlagToVisibility(visibility string) (registryv1alpha1.CuratedPlug
 	case privateVisibility:
 		return registryv1alpha1.CuratedPluginVisibility_CURATED_PLUGIN_VISIBILITY_PRIVATE, nil
 	default:
-		return 0, fmt.Errorf("invalid visibility: %s, expected one of %s", visibility, stringutil.SliceToString(allVisibiltyStrings))
+		return 0, fmt.Errorf("invalid visibility: %s, expected one of %s", visibility, xstrings.SliceToString(allVisibilityStrings))
 	}
 }
 
