@@ -1,4 +1,4 @@
-// Copyright 2020-2024 Buf Technologies, Inc.
+// Copyright 2020-2025 Buf Technologies, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -21,7 +21,7 @@ import (
 	"strings"
 	"sync"
 
-	"github.com/bufbuild/buf/private/pkg/slicesext"
+	"buf.build/go/standard/xslices"
 	"github.com/bufbuild/buf/private/pkg/storage"
 	"github.com/bufbuild/buf/private/pkg/syserror"
 	"github.com/google/uuid"
@@ -89,7 +89,7 @@ func (a *addedModule) IsTarget() bool {
 // OpaqueID returns the OpaqueID of the addedModule.
 func (a *addedModule) OpaqueID() string {
 	if a.remoteModuleKey != nil {
-		return a.remoteModuleKey.ModuleFullName().String()
+		return a.remoteModuleKey.FullName().String()
 	}
 	return a.localModule.OpaqueID()
 }
@@ -121,14 +121,14 @@ func (a *addedModule) ToModule(
 				return nil, syserror.Newf("expected 1 ModuleData, got %d", len(moduleDatas))
 			}
 			moduleData := moduleDatas[0]
-			if moduleData.ModuleKey().ModuleFullName() == nil {
-				return nil, syserror.New("got nil ModuleFullName for a ModuleKey returned from a ModuleDataProvider")
+			if moduleData.ModuleKey().FullName() == nil {
+				return nil, syserror.New("got nil FullName for a ModuleKey returned from a ModuleDataProvider")
 			}
-			if a.remoteModuleKey.ModuleFullName().String() != moduleData.ModuleKey().ModuleFullName().String() {
+			if a.remoteModuleKey.FullName().String() != moduleData.ModuleKey().FullName().String() {
 				return nil, syserror.Newf(
-					"mismatched ModuleFullName from ModuleDataProvider: input %q, output %q",
-					a.remoteModuleKey.ModuleFullName().String(),
-					moduleData.ModuleKey().ModuleFullName().String(),
+					"mismatched FullName from ModuleDataProvider: input %q, output %q",
+					a.remoteModuleKey.FullName().String(),
+					moduleData.ModuleKey().FullName().String(),
 				)
 			}
 			return moduleData, nil
@@ -161,115 +161,58 @@ func (a *addedModule) ToModule(
 		}
 		return moduleData.V1Beta1OrV1BufLockObjectData()
 	}
-	// Imagine the following scenario:
+	// getDepModuleKeysB5 gets the dependencies for the specific Module.
 	//
-	//   module-a (local)
-	//     README.md
-	//     a.proto
-	//     b.proto
-	//   module-b:c1
-	//     README.md
-	//     c.proto
-	//     d.proto
-	//   module-b:c2
-	//     README.md
-	//     c.proto
-	//     d.proto
-	//   module-c:c1
-	//     e.proto
-	//     f.proto
-	//   module-c:c2
-	//     e.proto
-	//     f.proto
-	//     g.proto
+	// This is needed to calculate the digest for the Module. A Module constructed from this
+	// ModuleData as the target will require all Modules referenced by its DepModuleKeys to
+	// be present in the ModuleSet.
 	//
-	// Then, you have this dependency graph:
+	// Modules that depend on this remote Module will include this Module and its data.
+	// However all the dependencies of the remote Module may not be present in the parents ModuleSet.
+	// As the target Module will use its direct dependencies to resolve the dependencies required.
+	// The digest of the remote Module is however, unchanged. It is calculated based on the contents
+	// and its dependencies, not the dependencies of the parent ModuleSet.
 	//
-	// module-a -> module-b:c1, module-c:c2
-	// module-b:c1 -> module-c:c1
+	// In contrast, a local Module dependency can be thought of as a ModuleKey at the latest commit.
+	// It will always use the bucket and dependencies, which may be resolved recursively for
+	// dependencies on other local Modules, to calculate its digest.
+	// This is the difference between the ModuleData digest calculation and the Module
+	// digest calculation. As remote Modules are required to have all their dependencies as
+	// ModuleKeys, they can calculate their digest directly from the contents and dependencies,
+	// without needing to recursively resolve the digest as local Modules do.
 	//
-	// Note that module-b depends on an earlier commit of module-c than module-a does.
+	// For example, consider the following modules at commits with their dependencies:
+	// ```
+	// X:C1			(X has no dependencies)
+	// A:C1 -> X:C1		(A depends on X)
+	// B:C1 -> A:C1 ~> X:C1 (B depends on A, transitive dependency on X)
+	// A:C2			(A removes the dependency on X)
+	// C:C1 -> A:C2, B:C1	(C depends on A and B, X is not a dependency)
+	// ```
+	// The ModuleSet for C:C1 will include B:C1 and A:C2, but not A:C1 or X:C1.
+	// This is because for C:C1 it will use the direct dependencies to resolve its dependencies.
+	// A is required by both B:C1 and C:C1, the latest A:C2 is chosen.
 	//
-	// If we were to just use the dependencies in the ModuleSet to compute the digest, the following
-	// would happen as a calculation:
+	// The ModuleSet for B:C1 will include A:C1 and X:C1.
+	// When calculating the digest for B:C1 in the ModuleSet of C:C1, the ModuleSet
+	// ModuleDeps cannot be used to resolve the dependencies of B:C1. It must use
+	// the dependencies of B:C1, which are A:C1 and X:C1, not A:C2.
 	//
-	//   DIGEST(module-a) = digest(
-	//     // module-a contents
-	//     README.md,
-	//     a.proto,
-	//     b.proto,
-	//     // module-b:c1 digest
-	//     DIGEST(
-	//       README.md,
-	//       c.proto,
-	//       d.proto,
-	//       // module-c:c2 digest
-	//       DIGEST(
-	//         README.md,
-	//         e.proto,
-	//         f.proto,
-	//         g.proto,
-	//       ),
-	//     ),
-	//     // module-c:c2 digest
-	//     DIGEST(
-	//         README.md,
-	//         e.proto,
-	//         f.proto,
-	//         g.proto,
-	//     ),
-	//   )
-	//
-	// Note that to compute the digest of module-b:c1, we would actually use the digest of
-	// module-c:c2, as opposed to module-c:c1, since within the ModuleSet, we would resolve
-	// to use module-c:c2 instead of module-c:c1.
-	//
-	// We should be using module-c:c1 to compute the digest of module-b:c1:
-	//
-	//   DIGEST(module-a) = digest(
-	//     // module-a contents
-	//     README.md,
-	//     a.proto,
-	//     b.proto,
-	//     // module-b:c1 digest
-	//     DIGEST(
-	//       README.md,
-	//       c.proto,
-	//       d.proto,
-	//       // module-c:c1 digest
-	//       DIGEST(
-	//         README.md,
-	//         e.proto,
-	//         f.proto,
-	//       ),
-	//     ),
-	//     // module-c:c2 digest
-	//     DIGEST(
-	//         README.md,
-	//         e.proto,
-	//         f.proto,
-	//         g.proto,
-	//     ),
-	//   )
-	//
-	// To accomplish this, we need to take the dependencies of the declared ModuleKeys (ie what
-	// the Module actually says is in its buf.lock). This function enables us to do that for
-	// digest calculations. Within the Module, we say that if we get a remote Module, use the
-	// declared ModuleKeys instead of whatever Module we have resolved to for a given ModuleFullName.
-	getDeclaredDepModuleKeysB5 := func() ([]ModuleKey, error) {
+	// This is used for digest calculations. It is not used otherwise.
+	getDepModuleKeysB5 := func() ([]ModuleKey, error) {
 		moduleData, err := getModuleData()
 		if err != nil {
 			return nil, err
 		}
-		declaredDepModuleKeys, err := moduleData.DeclaredDepModuleKeys()
+		depModuleKeys, err := moduleData.DepModuleKeys()
 		if err != nil {
 			return nil, err
 		}
-		if len(declaredDepModuleKeys) == 0 {
+		if len(depModuleKeys) == 0 {
 			return nil, nil
 		}
 		var digestType DigestType
-		for i, moduleKey := range declaredDepModuleKeys {
+		for i, moduleKey := range depModuleKeys {
 			digest, err := moduleKey.Digest()
 			if err != nil {
 				return nil, err
@@ -277,18 +220,18 @@ func (a *addedModule) ToModule(
 			if i == 0 {
 				digestType = digest.Type()
 			} else if digestType != digest.Type() {
-				return nil, syserror.Newf("multiple digest types found in DeclaredDepModuleKeys: %v, %v", digestType, digest.Type())
+				return nil, syserror.Newf("multiple digest types found in DepModuleKeys: %v, %v", digestType, digest.Type())
 			}
 		}
 		switch digestType {
 		case DigestTypeB4:
-			// The declared ModuleKey dependencies for a commit may be stored in v1 buf.lock file,
+			// The ModuleKey dependencies for a commit may be stored in v1 buf.lock file,
 			// in which case they will use B4 digests. B4 digests aren't allowed to be used as
 			// input to the B5 digest calculation, so we perform a call to convert all ModuleKeys
 			// from B4 to B5 by using the commit provider.
-			commitKeysToFetch := make([]CommitKey, len(declaredDepModuleKeys))
-			for i, declaredDepModuleKey := range declaredDepModuleKeys {
-				commitKey, err := NewCommitKey(declaredDepModuleKey.ModuleFullName().Registry(), declaredDepModuleKey.CommitID(), DigestTypeB5)
+			commitKeysToFetch := make([]CommitKey, len(depModuleKeys))
+			for i, depModuleKey := range depModuleKeys {
+				commitKey, err := NewCommitKey(depModuleKey.FullName().Registry(), depModuleKey.CommitID(), DigestTypeB5)
 				if err != nil {
 					return nil, err
 				}
@@ -301,12 +244,12 @@ func (a *addedModule) ToModule(
 			if len(commits) != len(commitKeysToFetch) {
 				return nil, syserror.Newf("expected %d commit(s), got %d", commitKeysToFetch, len(commits))
 			}
-			return slicesext.Map(commits, func(commit Commit) ModuleKey {
+			return xslices.Map(commits, func(commit Commit) ModuleKey {
 				return commit.ModuleKey()
 			}), nil
 		case DigestTypeB5:
-			// No need to fetch b5 digests - we've already got them stored in the module's declared dependencies.
-			return declaredDepModuleKeys, nil
+			// No need to fetch b5 digests - we've already got them stored in the module's dependencies.
+			return depModuleKeys, nil
 		default:
 			return nil, syserror.Newf("unsupported digest type: %v", digestType)
 		}
@@ -316,13 +259,13 @@ func (a *addedModule) ToModule(
 		getBucket,
 		"",
 		"",
-		a.remoteModuleKey.ModuleFullName(),
+		a.remoteModuleKey.FullName(),
 		a.remoteModuleKey.CommitID(),
 		a.isTarget,
 		false,
 		getV1BufYAMLObjectData,
 		getV1BufLockObjectData,
-		getDeclaredDepModuleKeysB5,
+		getDepModuleKeysB5,
 		a.remoteTargetPaths,
 		a.remoteTargetExcludePaths,
 		"",
@@ -343,15 +286,15 @@ func (a *addedModule) ToModule(
 //
 // When returned, all modules have unique opaqueIDs and Digests.
 //
-// Note: Modules with the same ModuleFullName will automatically have the same commit and Digest after this,
-// as there will be exactly one Module with a given ModuleFullName, given that an OpaqueID will be equal
-// for Modules with equal ModuleFullNames.
+// Note: Modules with the same FullName will automatically have the same commit and Digest after this,
+// as there will be exactly one Module with a given FullName, given that an OpaqueID will be equal
+// for Modules with equal FullNames.
 func getUniqueSortedAddedModulesByOpaqueID(
 	ctx context.Context,
 	commitProvider CommitProvider,
 	addedModules []*addedModule,
 ) ([]*addedModule, error) {
-	opaqueIDToAddedModules := slicesext.ToValuesMap(addedModules, (*addedModule).OpaqueID)
+	opaqueIDToAddedModules := xslices.ToValuesMap(addedModules, (*addedModule).OpaqueID)
 	resultAddedModules := make([]*addedModule, 0, len(opaqueIDToAddedModules))
 	for _, addedModulesForOpaqueID := range opaqueIDToAddedModules {
 		resultAddedModule, err := selectAddedModuleForOpaqueID(ctx, commitProvider, addedModulesForOpaqueID)
@@ -370,7 +313,7 @@ func getUniqueSortedAddedModulesByOpaqueID(
 }
 
 // selectAddedModuleForOpaqueID selects the single addedModule that should be used for a list
-// of addedModules that all have ths same OpaqueID.
+// of addedModules that all have the same OpaqueID.
 //
 // Note from earlier, not deleting:
 //
@@ -384,7 +327,7 @@ func selectAddedModuleForOpaqueID(
 	addedModules []*addedModule,
 ) (*addedModule, error) {
 	// First, we see if there are any target Modules. If so, we prefer those.
-	targetAddedModules := slicesext.Filter(addedModules, (*addedModule).IsTarget)
+	targetAddedModules := xslices.Filter(addedModules, (*addedModule).IsTarget)
 	switch len(targetAddedModules) {
 	case 0:
 		// We have no target Modules. We will select a non-target Module via
@@ -411,7 +354,7 @@ func selectAddedModuleForOpaqueIDIgnoreTargeting(
 	addedModules []*addedModule,
 ) (*addedModule, error) {
 	// Now, we see if there are any local Modules. If so, we prefer those
-	localAddedModules := slicesext.Filter(addedModules, (*addedModule).IsLocal)
+	localAddedModules := xslices.Filter(addedModules, (*addedModule).IsLocal)
 	switch len(localAddedModules) {
 	case 0:
 		// We have no local Modules. We will select a remote Module.
@@ -430,9 +373,9 @@ func selectAddedModuleForOpaqueIDIgnoreTargeting(
 // has already been taken into account.
 //
 // All addedModules are assumed to have the same OpaqueID, and therefore the same
-// ModuleFullName, since they are remote Modules. We validate this.
+// FullName, since they are remote Modules. We validate this.
 //
-// Note that there may be straight duplicates, ie two modules with the same ModuleFullName and CommitID! This
+// Note that there may be straight duplicates, ie two modules with the same FullName and CommitID! This
 // function deduplicates these.
 //
 // The ModuleKey with the latest create time is used.
@@ -453,20 +396,20 @@ func selectRemoteAddedModuleForOpaqueIDIgnoreTargeting(
 	if len(addedModules) == 1 {
 		return addedModules[0], nil
 	}
-	if moduleFullNameStrings := slicesext.ToUniqueSorted(
-		slicesext.Map(
+	if moduleFullNameStrings := xslices.ToUniqueSorted(
+		xslices.Map(
 			addedModules,
-			func(addedModule *addedModule) string { return addedModule.remoteModuleKey.ModuleFullName().String() },
+			func(addedModule *addedModule) string { return addedModule.remoteModuleKey.FullName().String() },
 		),
 	); len(moduleFullNameStrings) > 1 {
-		return nil, syserror.Newf("multiple ModuleFullNames detected in selectRemoteAddedModuleForOpaqueIDIgnoreTargeting: %s", strings.Join(moduleFullNameStrings, ", "))
+		return nil, syserror.Newf("multiple FullNames detected in selectRemoteAddedModuleForOpaqueIDIgnoreTargeting: %s", strings.Join(moduleFullNameStrings, ", "))
 	}
 
-	// We now know that we have >1 addedModules, and all of them have a remoteModuleKey, and all the remoteModuleKeys have the same ModuleFullName.
+	// We now know that we have >1 addedModules, and all of them have a remoteModuleKey, and all the remoteModuleKeys have the same FullName.
 
 	// Now, we deduplicate by commit ID. If we end up with a single Module, we return that, otherwise we select exactly one Module
 	// based on the create time of the corresponding commit ID.
-	commitIDToAddedModules := slicesext.ToValuesMap(
+	commitIDToAddedModules := xslices.ToValuesMap(
 		addedModules,
 		func(addedModule *addedModule) uuid.UUID { return addedModule.remoteModuleKey.CommitID() },
 	)
@@ -480,7 +423,7 @@ func selectRemoteAddedModuleForOpaqueIDIgnoreTargeting(
 
 	// We now know that we have non-unique remote added Modules, and have selected exactly one addedModule per commit ID.
 
-	uniqueModuleKeys := slicesext.Map(
+	uniqueModuleKeys := xslices.Map(
 		uniqueAddedModules,
 		func(addedModule *addedModule) ModuleKey {
 			return addedModule.remoteModuleKey
