@@ -21,10 +21,10 @@ import (
 
 	modulev1 "buf.build/gen/go/bufbuild/registry/protocolbuffers/go/buf/registry/module/v1"
 	modulev1beta1 "buf.build/gen/go/bufbuild/registry/protocolbuffers/go/buf/registry/module/v1beta1"
+	"buf.build/go/standard/xslices"
 	"github.com/bufbuild/buf/private/bufpkg/bufcas"
 	"github.com/bufbuild/buf/private/bufpkg/bufmodule"
 	"github.com/bufbuild/buf/private/bufpkg/bufparse"
-	"github.com/bufbuild/buf/private/pkg/slicesext"
 	"github.com/bufbuild/buf/private/pkg/storage"
 	"github.com/bufbuild/buf/private/pkg/uuidutil"
 	"github.com/google/uuid"
@@ -197,7 +197,7 @@ func commitIDToV1ProtoResourceRef(commitID uuid.UUID) *modulev1.ResourceRef {
 }
 
 func commitIDsToV1ProtoResourceRefs(commitIDs []uuid.UUID) []*modulev1.ResourceRef {
-	return slicesext.Map(commitIDs, commitIDToV1ProtoResourceRef)
+	return xslices.Map(commitIDs, commitIDToV1ProtoResourceRef)
 }
 
 func commitIDToV1Beta1ProtoResourceRef(commitID uuid.UUID) *modulev1beta1.ResourceRef {
@@ -209,7 +209,7 @@ func commitIDToV1Beta1ProtoResourceRef(commitID uuid.UUID) *modulev1beta1.Resour
 }
 
 func commitIDsToV1Beta1ProtoResourceRefs(commitIDs []uuid.UUID) []*modulev1beta1.ResourceRef {
-	return slicesext.Map(commitIDs, commitIDToV1Beta1ProtoResourceRef)
+	return xslices.Map(commitIDs, commitIDToV1Beta1ProtoResourceRef)
 }
 
 func moduleRefToV1ProtoResourceRef(moduleRef bufparse.Ref) *modulev1.ResourceRef {
@@ -227,7 +227,7 @@ func moduleRefToV1ProtoResourceRef(moduleRef bufparse.Ref) *modulev1.ResourceRef
 }
 
 func moduleRefsToV1ProtoResourceRefs(moduleRefs []bufparse.Ref) []*modulev1.ResourceRef {
-	return slicesext.Map(moduleRefs, moduleRefToV1ProtoResourceRef)
+	return xslices.Map(moduleRefs, moduleRefToV1ProtoResourceRef)
 }
 
 func moduleRefToV1Beta1ProtoResourceRef(moduleRef bufparse.Ref) *modulev1beta1.ResourceRef {
@@ -245,7 +245,7 @@ func moduleRefToV1Beta1ProtoResourceRef(moduleRef bufparse.Ref) *modulev1beta1.R
 }
 
 func moduleRefsToV1Beta1ProtoResourceRefs(moduleRefs []bufparse.Ref) []*modulev1beta1.ResourceRef {
-	return slicesext.Map(moduleRefs, moduleRefToV1Beta1ProtoResourceRef)
+	return xslices.Map(moduleRefs, moduleRefToV1Beta1ProtoResourceRef)
 }
 
 // We have to make sure all the below is updated if a field is added.
@@ -366,7 +366,7 @@ func v1beta1ProtoFileToV1ProtoFile(
 func v1beta1ProtoFilesToV1ProtoFiles(
 	v1beta1ProtoFiles []*modulev1beta1.File,
 ) []*modulev1.File {
-	return slicesext.Map(v1beta1ProtoFiles, v1beta1ProtoFileToV1ProtoFile)
+	return xslices.Map(v1beta1ProtoFiles, v1beta1ProtoFileToV1ProtoFile)
 }
 
 func v1beta1ProtoScopedLabelRefToV1ProtoScopedLabelRef(
@@ -395,7 +395,7 @@ func v1beta1ProtoScopedLabelRefToV1ProtoScopedLabelRef(
 func v1beta1ProtoScopedLabelRefsToV1ProtoScopedLabelRefs(
 	v1beta1ProtoScopedLabelRefs []*modulev1beta1.ScopedLabelRef,
 ) []*modulev1.ScopedLabelRef {
-	return slicesext.Map(v1beta1ProtoScopedLabelRefs, v1beta1ProtoScopedLabelRefToV1ProtoScopedLabelRef)
+	return xslices.Map(v1beta1ProtoScopedLabelRefs, v1beta1ProtoScopedLabelRefToV1ProtoScopedLabelRef)
 }
 
 func v1beta1ProtoUploadRequestContentToV1ProtoUploadRequestContent(
