@@ -21,12 +21,12 @@ import (
 	"io/fs"
 	"time"
 
+	"buf.build/go/standard/xlog/xslog"
+	"buf.build/go/standard/xslices"
 	"github.com/bufbuild/buf/private/bufpkg/bufconfig"
 	"github.com/bufbuild/buf/private/bufpkg/bufmodule"
 	"github.com/bufbuild/buf/private/bufpkg/bufparse"
 	"github.com/bufbuild/buf/private/pkg/dag"
-	"github.com/bufbuild/buf/private/pkg/slicesext"
-	"github.com/bufbuild/buf/private/pkg/slogext"
 	"github.com/bufbuild/buf/private/pkg/storage"
 	"github.com/bufbuild/buf/private/pkg/storage/storagemem"
 	"github.com/bufbuild/buf/private/pkg/storage/storageos"
@@ -199,7 +199,7 @@ func (o *omniProvider) GetModuleDatasForModuleKeys(
 	if _, err := bufparse.FullNameStringToUniqueValue(moduleKeys); err != nil {
 		return nil, err
 	}
-	return slicesext.MapError(
+	return xslices.MapError(
 		moduleKeys,
 		func(moduleKey bufmodule.ModuleKey) (bufmodule.ModuleData, error) {
 			return o.getModuleDataForModuleKey(ctx, moduleKey)
@@ -311,7 +311,7 @@ func (o *omniProvider) getModuleDataForModuleKey(
 	if err != nil {
 		return nil, err
 	}
-	depModuleKeys, err := slicesext.MapError(
+	depModuleKeys, err := xslices.MapError(
 		moduleDeps,
 		func(moduleDep bufmodule.ModuleDep) (bufmodule.ModuleKey, error) {
 			return bufmodule.ModuleToModuleKey(moduleDep, digest.Type())
@@ -344,7 +344,7 @@ func newModuleSet(
 	// may be nil
 	commitIDToCreateTime map[uuid.UUID]time.Time,
 ) (bufmodule.ModuleSet, error) {
-	moduleSetBuilder := bufmodule.NewModuleSetBuilder(context.Background(), slogext.NopLogger, bufmodule.NopModuleDataProvider, bufmodule.NopCommitProvider)
+	moduleSetBuilder := bufmodule.NewModuleSetBuilder(context.Background(), xslog.NopLogger, bufmodule.NopModuleDataProvider, bufmodule.NopCommitProvider)
 	for i, moduleData := range moduleDatas {
 		if err := addModuleDataToModuleSetBuilder(
 			moduleSetBuilder,
@@ -510,5 +510,5 @@ func addModuleToGraphRec(
 }
 
 func boolCount(bools ...bool) int {
-	return slicesext.Count(bools, func(value bool) bool { return value })
+	return xslices.Count(bools, func(value bool) bool { return value })
 }
