@@ -1,4 +1,4 @@
-// Copyright 2020-2024 Buf Technologies, Inc.
+// Copyright 2020-2025 Buf Technologies, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -25,9 +25,9 @@ func TestInterfaceSliceOrStringToCommaSepString(t *testing.T) {
 	testInterfaceSliceOrStringToCommaSepString(t, "mystring", "mystring")
 	testInterfaceSliceOrStringToCommaSepString(
 		t,
-		[]interface{}{
-			interface{}("mystring"),
-			interface{}("mystring2"),
+		[]any{
+			any("mystring"),
+			any("mystring2"),
 		},
 		"mystring,mystring2",
 	)
@@ -37,7 +37,7 @@ func TestInterfaceSliceOrStringToCommaSepString(t *testing.T) {
 	require.Error(t, err)
 }
 
-func testInterfaceSliceOrStringToCommaSepString(t *testing.T, in interface{}, expected string) {
+func testInterfaceSliceOrStringToCommaSepString(t *testing.T, in any, expected string) {
 	v, err := InterfaceSliceOrStringToCommaSepString(in)
 	require.NoError(t, err)
 	require.Equal(t, expected, v)
