@@ -1,4 +1,4 @@
-// Copyright 2020-2024 Buf Technologies, Inc.
+// Copyright 2020-2025 Buf Technologies, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -19,7 +19,7 @@ import (
 	"io"
 	"log/slog"
 
-	"github.com/bufbuild/buf/private/pkg/app/appext"
+	"buf.build/go/app/appext"
 	"github.com/bufbuild/buf/private/pkg/zapapp"
 	"go.uber.org/zap/exp/zapslog"
 )
@@ -35,5 +35,5 @@ func NewLogger(writer io.Writer, logLevel appext.LogLevel, logFormat appext.LogF
 	if err != nil {
 		return nil, err
 	}
-	return slog.New(zapslog.NewHandler(core)), nil
+	return slog.New(zapslog.NewHandler(core, zapslog.AddStacktraceAt(slog.LevelError+1))), nil
 }
